/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "Dictionary.TxtWord",
        "sources": [
            "Dictionary/TxtWord.pyx"
        ]
    },
    "module_name": "Dictionary.TxtWord"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__Dictionary__TxtWord
#define __PYX_HAVE_API__Dictionary__TxtWord
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "Dictionary/TxtWord.pyx",
  "stringsource",
};

/*--- Type declarations ---*/
struct __pyx_obj_10Dictionary_4Word_Word;
struct __pyx_obj_10Dictionary_7TxtWord_TxtWord;

/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_10Dictionary_4Word_Word {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtab;
  PyObject *name;
};


/* "Dictionary/TxtWord.pxd":4
 * 
 * 
 * cdef class TxtWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __flags
 */
struct __pyx_obj_10Dictionary_7TxtWord_TxtWord {
  struct __pyx_obj_10Dictionary_4Word_Word __pyx_base;
  PyObject *__pyx___flags;
};



/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_10Dictionary_4Word_Word {
  int (*charCount)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_10Dictionary_4Word_Word *, PyObject *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*toCharacters)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtabptr_10Dictionary_4Word_Word;


/* "Dictionary/TxtWord.pyx":1
 * cdef class TxtWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, name: str, flag=None):
 */

struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord {
  struct __pyx_vtabstruct_10Dictionary_4Word_Word __pyx_base;
  PyObject *(*addFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*removeFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*verbType)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*samePos)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isNominal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPassive)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAbbreviation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isInterjection)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDuplicate)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isHeader)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPureAdjective)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPronoun)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isQuestion)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteau)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDeterminer)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isConjunction)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isAdverb)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPostP)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauEndingWithSI)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauFacedVowelEllipsis)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPortmanteauFacedSoftening)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isSuffix)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isNumeral)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*notObeysVowelHarmonyDuringAgglutination)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*obeysAndNotObeysVowelHarmonyDuringAgglutination)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*rootSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*rootSoftenAndNotSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*verbSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*nounSoftenDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*endingKChangesIntoG)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*isExceptional)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*duplicatesDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*duplicatesAndNotDuplicatesDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIdropsDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIDropsAndNotDropDuringSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesRelativeSuffixKi)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesRelativeSuffixKu)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*consonantSMayInsertedDuringPossesiveSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*lastIdropsDuringPassiveSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*vowelAChangesToIDuringYSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*vowelEChangesToIDuringYSuffixation)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesSuffixIRAsAorist)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*takesSuffixDIRAsFactitive)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*showsSuRegularities)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch);
  int (*containsFlag)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *__pyx_vtabptr_10Dictionary_7TxtWord_TxtWord;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* CallNextTpDealloc.proto */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_dealloc);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_10Dictionary_7TxtWord_7TxtWord_addFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_10Dictionary_7TxtWord_7TxtWord_removeFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_10Dictionary_7TxtWord_7TxtWord_verbType(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_samePos(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_word, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isNominal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPassive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isAbbreviation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isInterjection(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isDuplicate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isHeader(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPureAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPronoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isQuestion(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isVerb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteau(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isDeterminer(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isConjunction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdverb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPostP(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauEndingWithSI(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedVowelEllipsis(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedSoftening(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isSuffix(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isProperNoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPlural(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isNumeral(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isReal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isFraction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isTime(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isDate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPercent(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isRange(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isOrdinal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_notObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_obeysAndNotObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenAndNotSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_verbSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_nounSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_endingKChangesIntoG(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isExceptional(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesAndNotDuplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIDropsAndNotDropDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKi(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKu(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_consonantSMayInsertedDuringPossesiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringPassiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelAChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelEChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixIRAsAorist(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixDIRAsFactitive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_showsSuRegularities(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_containsFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'Dictionary.Word' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Word_Word = 0;

/* Module declarations from 'Dictionary.TxtWord' */
static PyTypeObject *__pyx_ptype_10Dictionary_7TxtWord_TxtWord = 0;
static PyObject *__pyx_f_10Dictionary_7TxtWord___pyx_unpickle_TxtWord__set_state(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "Dictionary.TxtWord"
extern int __pyx_module_is_main_Dictionary__TxtWord;
int __pyx_module_is_main_Dictionary__TxtWord = 0;

/* Implementation of 'Dictionary.TxtWord' */
static PyObject *__pyx_builtin_super;
static const char __pyx_k_[] = "";
static const char __pyx_k_EK[] = "EK";
static const char __pyx_k__2[] = " ";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_str[] = "__str__";
static const char __pyx_k_F1P1[] = "F1P1";
static const char __pyx_k_F2P1[] = "F2P1";
static const char __pyx_k_F2PL[] = "F2PL";
static const char __pyx_k_F3P1[] = "F3P1";
static const char __pyx_k_F4P1[] = "F4P1";
static const char __pyx_k_F4PL[] = "F4PL";
static const char __pyx_k_F4PR[] = "F4PR";
static const char __pyx_k_F4PW[] = "F4PW";
static const char __pyx_k_F5P1[] = "F5P1";
static const char __pyx_k_F5PL[] = "F5PL";
static const char __pyx_k_F5PR[] = "F5PR";
static const char __pyx_k_F5PW[] = "F5PW";
static const char __pyx_k_F6P1[] = "F6P1";
static const char __pyx_k_F_SD[] = "F_SD";
static const char __pyx_k_F_UD[] = "F_UD";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_flag[] = "flag";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_F_DIR[] = "F_DIR";
static const char __pyx_k_F_GIR[] = "F_GIR";
static const char __pyx_k_F_GUD[] = "F_GUD";
static const char __pyx_k_IS_CA[] = "IS_CA";
static const char __pyx_k_IS_EX[] = "IS_EX";
static const char __pyx_k_IS_KG[] = "IS_KG";
static const char __pyx_k_IS_KI[] = "IS_KI";
static const char __pyx_k_IS_KU[] = "IS_KU";
static const char __pyx_k_IS_OA[] = "IS_OA";
static const char __pyx_k_IS_SD[] = "IS_SD";
static const char __pyx_k_IS_ST[] = "IS_ST";
static const char __pyx_k_IS_SU[] = "IS_SU";
static const char __pyx_k_IS_UD[] = "IS_UD";
static const char __pyx_k_IS_UU[] = "IS_UU";
static const char __pyx_k_IS_ZM[] = "IS_ZM";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_F_GUDO[] = "F_GUDO";
static const char __pyx_k_IS_ADJ[] = "IS_ADJ";
static const char __pyx_k_IS_DET[] = "IS_DET";
static const char __pyx_k_IS_DUP[] = "IS_DUP";
static const char __pyx_k_IS_KIS[] = "IS_KIS";
static const char __pyx_k_IS_ORD[] = "IS_ORD";
static const char __pyx_k_IS_SDD[] = "IS_SDD";
static const char __pyx_k_IS_SII[] = "IS_SII";
static const char __pyx_k_IS_STT[] = "IS_STT";
static const char __pyx_k_IS_UDD[] = "IS_UDD";
static const char __pyx_k_IS_UUU[] = "IS_UUU";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_isDate[] = "isDate";
static const char __pyx_k_isReal[] = "isReal";
static const char __pyx_k_isTime[] = "isTime";
static const char __pyx_k_isVerb[] = "isVerb";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_remove[] = "remove";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_CL_FIIL[] = "CL_FIIL";
static const char __pyx_k_CL_ISIM[] = "CL_ISIM";
static const char __pyx_k_IS_BILE[] = "IS_BILE\305\236";
static const char __pyx_k_IS_B_SD[] = "IS_B_SD";
static const char __pyx_k_IS_B_SI[] = "IS_B_SI";
static const char __pyx_k_IS_B_UD[] = "IS_B_UD";
static const char __pyx_k_IS_CONJ[] = "IS_CONJ";
static const char __pyx_k_IS_DATE[] = "IS_DATE";
static const char __pyx_k_IS_QUES[] = "IS_QUES";
static const char __pyx_k_IS_SAYI[] = "IS_SAYI";
static const char __pyx_k_TxtWord[] = "TxtWord";
static const char __pyx_k_addFlag[] = "addFlag";
static const char __pyx_k_isPostP[] = "isPostP";
static const char __pyx_k_isRange[] = "isRange";
static const char __pyx_k_samePos[] = "samePos";
static const char __pyx_k_IS_KESIR[] = "IS_KESIR";
static const char __pyx_k_IS_POSTP[] = "IS_POSTP";
static const char __pyx_k_IS_RANGE[] = "IS_RANGE";
static const char __pyx_k_IS_ZAMAN[] = "IS_ZAMAN";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_isAdverb[] = "isAdverb";
static const char __pyx_k_isHeader[] = "isHeader";
static const char __pyx_k_isPlural[] = "isPlural";
static const char __pyx_k_isSuffix[] = "isSuffix";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_verbType[] = "verbType";
static const char __pyx_k_IS_ADVERB[] = "IS_ADVERB";
static const char __pyx_k_IS_HEADER[] = "IS_HEADER";
static const char __pyx_k_IS_INTERJ[] = "IS_INTERJ";
static const char __pyx_k_isNominal[] = "isNominal";
static const char __pyx_k_isNumeral[] = "isNumeral";
static const char __pyx_k_isOrdinal[] = "isOrdinal";
static const char __pyx_k_isPassive[] = "isPassive";
static const char __pyx_k_isPercent[] = "isPercent";
static const char __pyx_k_isPronoun[] = "isPronoun";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_IS_PERCENT[] = "IS_PERCENT";
static const char __pyx_k_IS_PUREADJ[] = "IS_PUREADJ";
static const char __pyx_k_PASSIVE_HN[] = "PASSIVE-HN";
static const char __pyx_k_isFraction[] = "isFraction";
static const char __pyx_k_isQuestion[] = "isQuestion";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_removeFlag[] = "removeFlag";
static const char __pyx_k_F1P1_NO_REF[] = "F1P1-NO-REF";
static const char __pyx_k_F2P1_NO_REF[] = "F2P1-NO-REF";
static const char __pyx_k_F3P1_NO_REF[] = "F3P1-NO-REF";
static const char __pyx_k_F4P1_NO_REF[] = "F4P1-NO-REF";
static const char __pyx_k_F4PL_NO_REF[] = "F4PL-NO-REF";
static const char __pyx_k_F4PR_NO_REF[] = "F4PR-NO-REF";
static const char __pyx_k_F4PW_NO_REF[] = "F4PW-NO-REF";
static const char __pyx_k_F5PL_NO_REF[] = "F5PL-NO-REF";
static const char __pyx_k_F5PR_NO_REF[] = "F5PR-NO-REF";
static const char __pyx_k_F5PW_NO_REF[] = "F5PW-NO-REF";
static const char __pyx_k_IS_REELSAYI[] = "IS_REELSAYI";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_isAdjective[] = "isAdjective";
static const char __pyx_k_isDuplicate[] = "isDuplicate";
static const char __pyx_k_containsFlag[] = "containsFlag";
static const char __pyx_k_isDeterminer[] = "isDeterminer";
static const char __pyx_k_isProperNoun[] = "isProperNoun";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_isConjunction[] = "isConjunction";
static const char __pyx_k_isExceptional[] = "isExceptional";
static const char __pyx_k_isPortmanteau[] = "isPortmanteau";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_isAbbreviation[] = "isAbbreviation";
static const char __pyx_k_isInterjection[] = "isInterjection";
static const char __pyx_k_isPureAdjective[] = "isPureAdjective";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_Dictionary_TxtWord[] = "Dictionary.TxtWord";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_endingKChangesIntoG[] = "endingKChangesIntoG";
static const char __pyx_k_showsSuRegularities[] = "showsSuRegularities";
static const char __pyx_k_pyx_unpickle_TxtWord[] = "__pyx_unpickle_TxtWord";
static const char __pyx_k_takesRelativeSuffixKi[] = "takesRelativeSuffixKi";
static const char __pyx_k_takesRelativeSuffixKu[] = "takesRelativeSuffixKu";
static const char __pyx_k_takesSuffixIRAsAorist[] = "takesSuffixIRAsAorist";
static const char __pyx_k_isPortmanteauEndingWithSI[] = "isPortmanteauEndingWithSI";
static const char __pyx_k_takesSuffixDIRAsFactitive[] = "takesSuffixDIRAsFactitive";
static const char __pyx_k_duplicatesDuringSuffixation[] = "duplicatesDuringSuffixation";
static const char __pyx_k_isPortmanteauFacedSoftening[] = "isPortmanteauFacedSoftening";
static const char __pyx_k_lastIdropsDuringSuffixation[] = "lastIdropsDuringSuffixation";
static const char __pyx_k_nounSoftenDuringSuffixation[] = "nounSoftenDuringSuffixation";
static const char __pyx_k_rootSoftenDuringSuffixation[] = "rootSoftenDuringSuffixation";
static const char __pyx_k_verbSoftenDuringSuffixation[] = "verbSoftenDuringSuffixation";
static const char __pyx_k_isPortmanteauFacedVowelEllipsis[] = "isPortmanteauFacedVowelEllipsis";
static const char __pyx_k_Incompatible_checksums_s_vs_0xe7[] = "Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))";
static const char __pyx_k_consonantSMayInsertedDuringPosse[] = "consonantSMayInsertedDuringPossesiveSuffixation";
static const char __pyx_k_duplicatesAndNotDuplicatesDuring[] = "duplicatesAndNotDuplicatesDuringSuffixation";
static const char __pyx_k_lastIDropsAndNotDropDuringSuffix[] = "lastIDropsAndNotDropDuringSuffixation";
static const char __pyx_k_lastIdropsDuringPassiveSuffixati[] = "lastIdropsDuringPassiveSuffixation";
static const char __pyx_k_notObeysVowelHarmonyDuringAgglut[] = "notObeysVowelHarmonyDuringAgglutination";
static const char __pyx_k_obeysAndNotObeysVowelHarmonyDuri[] = "obeysAndNotObeysVowelHarmonyDuringAgglutination";
static const char __pyx_k_rootSoftenAndNotSoftenDuringSuff[] = "rootSoftenAndNotSoftenDuringSuffixation";
static const char __pyx_k_vowelAChangesToIDuringYSuffixati[] = "vowelAChangesToIDuringYSuffixation";
static const char __pyx_k_vowelEChangesToIDuringYSuffixati[] = "vowelEChangesToIDuringYSuffixation";
static PyObject *__pyx_kp_u_;
static PyObject *__pyx_n_u_CL_FIIL;
static PyObject *__pyx_n_u_CL_ISIM;
static PyObject *__pyx_n_s_Dictionary_TxtWord;
static PyObject *__pyx_n_u_EK;
static PyObject *__pyx_n_u_F1P1;
static PyObject *__pyx_kp_u_F1P1_NO_REF;
static PyObject *__pyx_n_u_F2P1;
static PyObject *__pyx_kp_u_F2P1_NO_REF;
static PyObject *__pyx_n_u_F2PL;
static PyObject *__pyx_n_u_F3P1;
static PyObject *__pyx_kp_u_F3P1_NO_REF;
static PyObject *__pyx_n_u_F4P1;
static PyObject *__pyx_kp_u_F4P1_NO_REF;
static PyObject *__pyx_n_u_F4PL;
static PyObject *__pyx_kp_u_F4PL_NO_REF;
static PyObject *__pyx_n_u_F4PR;
static PyObject *__pyx_kp_u_F4PR_NO_REF;
static PyObject *__pyx_n_u_F4PW;
static PyObject *__pyx_kp_u_F4PW_NO_REF;
static PyObject *__pyx_n_u_F5P1;
static PyObject *__pyx_n_u_F5PL;
static PyObject *__pyx_kp_u_F5PL_NO_REF;
static PyObject *__pyx_n_u_F5PR;
static PyObject *__pyx_kp_u_F5PR_NO_REF;
static PyObject *__pyx_n_u_F5PW;
static PyObject *__pyx_kp_u_F5PW_NO_REF;
static PyObject *__pyx_n_u_F6P1;
static PyObject *__pyx_n_u_F_DIR;
static PyObject *__pyx_n_u_F_GIR;
static PyObject *__pyx_n_u_F_GUD;
static PyObject *__pyx_n_u_F_GUDO;
static PyObject *__pyx_n_u_F_SD;
static PyObject *__pyx_n_u_F_UD;
static PyObject *__pyx_n_u_IS_ADJ;
static PyObject *__pyx_n_u_IS_ADVERB;
static PyObject *__pyx_n_u_IS_BILE;
static PyObject *__pyx_n_u_IS_B_SD;
static PyObject *__pyx_n_u_IS_B_SI;
static PyObject *__pyx_n_u_IS_B_UD;
static PyObject *__pyx_n_u_IS_CA;
static PyObject *__pyx_n_u_IS_CONJ;
static PyObject *__pyx_n_u_IS_DATE;
static PyObject *__pyx_n_u_IS_DET;
static PyObject *__pyx_n_u_IS_DUP;
static PyObject *__pyx_n_u_IS_EX;
static PyObject *__pyx_n_u_IS_HEADER;
static PyObject *__pyx_n_u_IS_INTERJ;
static PyObject *__pyx_n_u_IS_KESIR;
static PyObject *__pyx_n_u_IS_KG;
static PyObject *__pyx_n_u_IS_KI;
static PyObject *__pyx_n_u_IS_KIS;
static PyObject *__pyx_n_u_IS_KU;
static PyObject *__pyx_n_u_IS_OA;
static PyObject *__pyx_n_u_IS_ORD;
static PyObject *__pyx_n_u_IS_PERCENT;
static PyObject *__pyx_n_u_IS_POSTP;
static PyObject *__pyx_n_u_IS_PUREADJ;
static PyObject *__pyx_n_u_IS_QUES;
static PyObject *__pyx_n_u_IS_RANGE;
static PyObject *__pyx_n_u_IS_REELSAYI;
static PyObject *__pyx_n_u_IS_SAYI;
static PyObject *__pyx_n_u_IS_SD;
static PyObject *__pyx_n_u_IS_SDD;
static PyObject *__pyx_n_u_IS_SII;
static PyObject *__pyx_n_u_IS_ST;
static PyObject *__pyx_n_u_IS_STT;
static PyObject *__pyx_n_u_IS_SU;
static PyObject *__pyx_n_u_IS_UD;
static PyObject *__pyx_n_u_IS_UDD;
static PyObject *__pyx_n_u_IS_UU;
static PyObject *__pyx_n_u_IS_UUU;
static PyObject *__pyx_n_u_IS_ZAMAN;
static PyObject *__pyx_n_u_IS_ZM;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xe7;
static PyObject *__pyx_kp_u_PASSIVE_HN;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_s_TxtWord;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_n_s_addFlag;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_consonantSMayInsertedDuringPosse;
static PyObject *__pyx_n_s_containsFlag;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_duplicatesAndNotDuplicatesDuring;
static PyObject *__pyx_n_s_duplicatesDuringSuffixation;
static PyObject *__pyx_n_s_endingKChangesIntoG;
static PyObject *__pyx_n_s_flag;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_isAbbreviation;
static PyObject *__pyx_n_s_isAdjective;
static PyObject *__pyx_n_s_isAdverb;
static PyObject *__pyx_n_s_isConjunction;
static PyObject *__pyx_n_s_isDate;
static PyObject *__pyx_n_s_isDeterminer;
static PyObject *__pyx_n_s_isDuplicate;
static PyObject *__pyx_n_s_isExceptional;
static PyObject *__pyx_n_s_isFraction;
static PyObject *__pyx_n_s_isHeader;
static PyObject *__pyx_n_s_isInterjection;
static PyObject *__pyx_n_s_isNominal;
static PyObject *__pyx_n_s_isNumeral;
static PyObject *__pyx_n_s_isOrdinal;
static PyObject *__pyx_n_s_isPassive;
static PyObject *__pyx_n_s_isPercent;
static PyObject *__pyx_n_s_isPlural;
static PyObject *__pyx_n_s_isPortmanteau;
static PyObject *__pyx_n_s_isPortmanteauEndingWithSI;
static PyObject *__pyx_n_s_isPortmanteauFacedSoftening;
static PyObject *__pyx_n_s_isPortmanteauFacedVowelEllipsis;
static PyObject *__pyx_n_s_isPostP;
static PyObject *__pyx_n_s_isPronoun;
static PyObject *__pyx_n_s_isProperNoun;
static PyObject *__pyx_n_s_isPureAdjective;
static PyObject *__pyx_n_s_isQuestion;
static PyObject *__pyx_n_s_isRange;
static PyObject *__pyx_n_s_isReal;
static PyObject *__pyx_n_s_isSuffix;
static PyObject *__pyx_n_s_isTime;
static PyObject *__pyx_n_s_isVerb;
static PyObject *__pyx_n_s_lastIDropsAndNotDropDuringSuffix;
static PyObject *__pyx_n_s_lastIdropsDuringPassiveSuffixati;
static PyObject *__pyx_n_s_lastIdropsDuringSuffixation;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_notObeysVowelHarmonyDuringAgglut;
static PyObject *__pyx_n_s_nounSoftenDuringSuffixation;
static PyObject *__pyx_n_s_obeysAndNotObeysVowelHarmonyDuri;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_TxtWord;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_remove;
static PyObject *__pyx_n_s_removeFlag;
static PyObject *__pyx_n_s_rootSoftenAndNotSoftenDuringSuff;
static PyObject *__pyx_n_s_rootSoftenDuringSuffixation;
static PyObject *__pyx_n_s_samePos;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_showsSuRegularities;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_super;
static PyObject *__pyx_n_s_takesRelativeSuffixKi;
static PyObject *__pyx_n_s_takesRelativeSuffixKu;
static PyObject *__pyx_n_s_takesSuffixDIRAsFactitive;
static PyObject *__pyx_n_s_takesSuffixIRAsAorist;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_verbSoftenDuringSuffixation;
static PyObject *__pyx_n_s_verbType;
static PyObject *__pyx_n_s_vowelAChangesToIDuringYSuffixati;
static PyObject *__pyx_n_s_vowelEChangesToIDuringYSuffixati;
static int __pyx_pf_10Dictionary_7TxtWord_7TxtWord___init__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_2addFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_4removeFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_6verbType(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_8samePos(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_word); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_10isNominal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_12isPassive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_14isAbbreviation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_16isInterjection(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_18isDuplicate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_20isHeader(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_22isAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_24isPureAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_26isPronoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_28isQuestion(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_30isVerb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_32isPortmanteau(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_34isDeterminer(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_36isConjunction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_38isAdverb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_40isPostP(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_42isPortmanteauEndingWithSI(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_44isPortmanteauFacedVowelEllipsis(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_46isPortmanteauFacedSoftening(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_48isSuffix(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_50isProperNoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_52isPlural(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_54isNumeral(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_56isReal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_58isFraction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_60isTime(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_62isDate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_64isPercent(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_66isRange(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_68isOrdinal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_70notObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_72obeysAndNotObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_74rootSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_76rootSoftenAndNotSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_78verbSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_80nounSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_82endingKChangesIntoG(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_84isExceptional(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_86duplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_88duplicatesAndNotDuplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_90lastIdropsDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_92lastIDropsAndNotDropDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_94takesRelativeSuffixKi(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_96takesRelativeSuffixKu(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_98consonantSMayInsertedDuringPossesiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_100lastIdropsDuringPassiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_102vowelAChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_104vowelEChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_106takesSuffixIRAsAorist(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_108takesSuffixDIRAsFactitive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_110showsSuRegularities(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_112containsFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_114__str__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_116__reduce_cython__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_118__setstate_cython__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_10Dictionary_7TxtWord___pyx_unpickle_TxtWord(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_10Dictionary_7TxtWord_TxtWord(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_243029568;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_codeobj__4;
/* Late includes */

/* "Dictionary/TxtWord.pyx":3
 * cdef class TxtWord(Word):
 * 
 *     def __init__(self, name: str, flag=None):             # <<<<<<<<<<<<<<
 *         """
 *         Another constructor of TxtWord class which takes a String name and a flag as inputs and calls its super class
 */

/* Python wrapper */
static int __pyx_pw_10Dictionary_7TxtWord_7TxtWord_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord___init__[] = "\n        Another constructor of TxtWord class which takes a String name and a flag as inputs and calls its super class\n        Word with given name. Then, creates a new list as flags and calls addFlag method with given flag.\n\n        PARAMETERS\n        ----------\n        name : str\n            String input.\n        flag : str\n            String input.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_10Dictionary_7TxtWord_7TxtWord___init__;
#endif
static int __pyx_pw_10Dictionary_7TxtWord_7TxtWord_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_flag = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_flag,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_flag);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = ((PyObject*)values[0]);
    __pyx_v_flag = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_name), (&PyUnicode_Type), 1, "name", 1))) __PYX_ERR(0, 3, __pyx_L1_error)
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord___init__(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self), __pyx_v_name, __pyx_v_flag);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_10Dictionary_7TxtWord_7TxtWord___init__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_flag) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "Dictionary/TxtWord.pyx":15
 *             String input.
 *         """
 *         super().__init__(name)             # <<<<<<<<<<<<<<
 *         self.__flags = []
 *         if flag is not None:
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord));
  __Pyx_GIVEREF(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord));
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_name) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_name);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Dictionary/TxtWord.pyx":16
 *         """
 *         super().__init__(name)
 *         self.__flags = []             # <<<<<<<<<<<<<<
 *         if flag is not None:
 *             self.addFlag(flag)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx___flags);
  __Pyx_DECREF(__pyx_v_self->__pyx___flags);
  __pyx_v_self->__pyx___flags = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "Dictionary/TxtWord.pyx":17
 *         super().__init__(name)
 *         self.__flags = []
 *         if flag is not None:             # <<<<<<<<<<<<<<
 *             self.addFlag(flag)
 * 
 */
  __pyx_t_4 = (__pyx_v_flag != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":18
 *         self.__flags = []
 *         if flag is not None:
 *             self.addFlag(flag)             # <<<<<<<<<<<<<<
 * 
 *     cpdef addFlag(self, str flag):
 */
    if (!(likely(PyUnicode_CheckExact(__pyx_v_flag))||((__pyx_v_flag) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_flag)->tp_name), 0))) __PYX_ERR(0, 18, __pyx_L1_error)
    __pyx_t_1 = ((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->addFlag(__pyx_v_self, ((PyObject*)__pyx_v_flag), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "Dictionary/TxtWord.pyx":17
 *         super().__init__(name)
 *         self.__flags = []
 *         if flag is not None:             # <<<<<<<<<<<<<<
 *             self.addFlag(flag)
 * 
 */
  }

  /* "Dictionary/TxtWord.pyx":3
 * cdef class TxtWord(Word):
 * 
 *     def __init__(self, name: str, flag=None):             # <<<<<<<<<<<<<<
 *         """
 *         Another constructor of TxtWord class which takes a String name and a flag as inputs and calls its super class
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":20
 *             self.addFlag(flag)
 * 
 *     cpdef addFlag(self, str flag):             # <<<<<<<<<<<<<<
 *         """
 *         The addFlag method takes a String flag as an input and adds given flag to the flags list.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_3addFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /*proto*/
static PyObject *__pyx_f_10Dictionary_7TxtWord_7TxtWord_addFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addFlag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_addFlag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_3addFlag)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_flag) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_flag);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":29
 *             String input to add.
 *         """
 *         self.__flags.append(flag)             # <<<<<<<<<<<<<<
 * 
 *     cpdef removeFlag(self, str flag):
 */
  if (unlikely(__pyx_v_self->__pyx___flags == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 29, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->__pyx___flags, __pyx_v_flag); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 29, __pyx_L1_error)

  /* "Dictionary/TxtWord.pyx":20
 *             self.addFlag(flag)
 * 
 *     cpdef addFlag(self, str flag):             # <<<<<<<<<<<<<<
 *         """
 *         The addFlag method takes a String flag as an input and adds given flag to the flags list.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.addFlag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_3addFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_2addFlag[] = "\n        The addFlag method takes a String flag as an input and adds given flag to the flags list.\n\n        PARAMETERS\n        ----------\n        flag : str\n            String input to add.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_3addFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addFlag (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_flag), (&PyUnicode_Type), 1, "flag", 1))) __PYX_ERR(0, 20, __pyx_L1_error)
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_2addFlag(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self), ((PyObject*)__pyx_v_flag));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_2addFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addFlag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_10Dictionary_7TxtWord_7TxtWord_addFlag(__pyx_v_self, __pyx_v_flag, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.addFlag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":31
 *         self.__flags.append(flag)
 * 
 *     cpdef removeFlag(self, str flag):             # <<<<<<<<<<<<<<
 *         """
 *         The removeFlag method takes a String flag as an input and removes given flag from the flags list.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_5removeFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /*proto*/
static PyObject *__pyx_f_10Dictionary_7TxtWord_7TxtWord_removeFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("removeFlag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_removeFlag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 31, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_5removeFlag)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_flag) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_flag);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 31, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":40
 *             String input to remove.
 *         """
 *         self.__flags.remove(flag)             # <<<<<<<<<<<<<<
 * 
 *     cpdef str verbType(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx___flags, __pyx_n_s_remove); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_flag) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_flag);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Dictionary/TxtWord.pyx":31
 *         self.__flags.append(flag)
 * 
 *     cpdef removeFlag(self, str flag):             # <<<<<<<<<<<<<<
 *         """
 *         The removeFlag method takes a String flag as an input and removes given flag from the flags list.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.removeFlag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_5removeFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_4removeFlag[] = "\n        The removeFlag method takes a String flag as an input and removes given flag from the flags list.\n\n        PARAMETERS\n        ----------\n        flag : str\n            String input to remove.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_5removeFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("removeFlag (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_flag), (&PyUnicode_Type), 1, "flag", 1))) __PYX_ERR(0, 31, __pyx_L1_error)
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_4removeFlag(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self), ((PyObject*)__pyx_v_flag));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_4removeFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("removeFlag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_10Dictionary_7TxtWord_7TxtWord_removeFlag(__pyx_v_self, __pyx_v_flag, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.removeFlag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":42
 *         self.__flags.remove(flag)
 * 
 *     cpdef str verbType(self):             # <<<<<<<<<<<<<<
 *         """
 *         The verbType method checks flags list and returns the corresponding cases.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_7verbType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_10Dictionary_7TxtWord_7TxtWord_verbType(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("verbType", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_verbType); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_7verbType)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 42, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":51
 *             the corresponding cases.
 *         """
 *         if "F1P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             There is no example in the Turkish dictionary.
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F1P1_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 51, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":55
 *             There is no example in the Turkish dictionary.
 *             """
 *             return "F1P1-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F2P1-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F1P1_NO_REF);
    __pyx_r = __pyx_kp_u_F1P1_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":51
 *             the corresponding cases.
 *         """
 *         if "F1P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             There is no example in the Turkish dictionary.
 */
  }

  /* "Dictionary/TxtWord.pyx":56
 *             """
 *             return "F1P1-NO-REF"
 *         if "F2P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F2P1-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F2P1_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":61
 *             suffix, can take PassiveHl suffix, can take CausativeT suffix. e.g. Do, g, iin
 *             """
 *             return "F2P1-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F3P1-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F2P1_NO_REF);
    __pyx_r = __pyx_kp_u_F2P1_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":56
 *             """
 *             return "F1P1-NO-REF"
 *         if "F2P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F2P1-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":62
 *             """
 *             return "F2P1-NO-REF"
 *         if "F3P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F3P1-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F3P1_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 62, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":67
 *             suffix, can take Passive Hl suffix, can take CausativeT suffix. e.g. Ak
 *             """
 *             return "F3P1-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F4P1-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F3P1_NO_REF);
    __pyx_r = __pyx_kp_u_F3P1_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":62
 *             """
 *             return "F2P1-NO-REF"
 *         if "F3P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F3P1-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":68
 *             """
 *             return "F3P1-NO-REF"
 *         if "F4P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4P1-NO-REF: The bare-form is a verb and depending on this attribute, the verb can't take PassiveHn
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F4P1_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 68, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":73
 *             suffix, can take CausativeT suffix. e.g. Aksa
 *             """
 *             return "F4P1-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F4PR-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F4P1_NO_REF);
    __pyx_r = __pyx_kp_u_F4P1_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":68
 *             """
 *             return "F3P1-NO-REF"
 *         if "F4P1-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4P1-NO-REF: The bare-form is a verb and depending on this attribute, the verb can't take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":74
 *             """
 *             return "F4P1-NO-REF"
 *         if "F4PR-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PR-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F4PR_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 74, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":79
 *             suffix, can take PassiveHl suffix, can take CausativeT suffix. e.g. evir, gster
 *             """
 *             return "F4PR-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F4PL-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F4PR_NO_REF);
    __pyx_r = __pyx_kp_u_F4PR_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":74
 *             """
 *             return "F4P1-NO-REF"
 *         if "F4PR-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PR-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":80
 *             """
 *             return "F4PR-NO-REF"
 *         if "F4PL-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PL-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F4PL_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 80, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":85
 *             suffix, can take CausativeT suffix. e.g. Azal, oal
 *             """
 *             return "F4PL-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F4PW-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F4PL_NO_REF);
    __pyx_r = __pyx_kp_u_F4PL_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":80
 *             """
 *             return "F4PR-NO-REF"
 *         if "F4PL-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PL-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":86
 *             """
 *             return "F4PL-NO-REF"
 *         if "F4PW-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PW-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F4PW_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 86, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":91
 *             suffix, can take PassiveN suffix, can take CausativeT suffix. e.g. Birle, boya
 *             """
 *             return "F4PW-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F5PL-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F4PW_NO_REF);
    __pyx_r = __pyx_kp_u_F4PW_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":86
 *             """
 *             return "F4PL-NO-REF"
 *         if "F4PW-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PW-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":92
 *             """
 *             return "F4PW-NO-REF"
 *         if "F5PL-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PL-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F5PL_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 92, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":97
 *             suffix, can take CausativeDHr suffix. e.g. al, kal
 *             """
 *             return "F5PL-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F5PR-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F5PL_NO_REF);
    __pyx_r = __pyx_kp_u_F5PL_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":92
 *             """
 *             return "F4PW-NO-REF"
 *         if "F5PL-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PL-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":98
 *             """
 *             return "F5PL-NO-REF"
 *         if "F5PR-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PR-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F5PR_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 98, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":103
 *             suffix, can take PassiveHl suffix, can take CausativeDHr suffix. e.g. Birle, z
 *             """
 *             return "F5PR-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F5PW-NO-REF" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F5PR_NO_REF);
    __pyx_r = __pyx_kp_u_F5PR_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":98
 *             """
 *             return "F5PL-NO-REF"
 *         if "F5PR-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PR-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":104
 *             """
 *             return "F5PR-NO-REF"
 *         if "F5PW-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PW-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_F5PW_NO_REF, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 104, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":109
 *             suffix, can take PassiveHl suffix, can take CausativeDHr suffix. e.g. Ye
 *             """
 *             return "F5PW-NO-REF"             # <<<<<<<<<<<<<<
 *         if "F1P1" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_kp_u_F5PW_NO_REF);
    __pyx_r = __pyx_kp_u_F5PW_NO_REF;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":104
 *             """
 *             return "F5PR-NO-REF"
 *         if "F5PW-NO-REF" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PW-NO-REF: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn
 */
  }

  /* "Dictionary/TxtWord.pyx":110
 *             """
 *             return "F5PW-NO-REF"
 *         if "F1P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F1P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F1P1, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 110, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":115
 *             take PassiveHl suffix, can take CausativeAr suffix, can take ReciprocalHs suffix. e.g. k, kop
 *             """
 *             return "F1P1"             # <<<<<<<<<<<<<<
 *         if "F2P1" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F1P1);
    __pyx_r = __pyx_n_u_F1P1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":110
 *             """
 *             return "F5PW-NO-REF"
 *         if "F1P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F1P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":116
 *             """
 *             return "F1P1"
 *         if "F2P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F2P1: The bare-form is a verb and depending on this attribute, the verb can can not PassiveHn suffix, can
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F2P1, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 116, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":121
 *             take CausativeHr suffix, can take CausativeDHr suffix, can take ReciprocalHs suffix. e.g. Bit, doy, d
 *             """
 *             return "F2P1"             # <<<<<<<<<<<<<<
 *         if "F2PL" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F2P1);
    __pyx_r = __pyx_n_u_F2P1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":116
 *             """
 *             return "F1P1"
 *         if "F2P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F2P1: The bare-form is a verb and depending on this attribute, the verb can can not PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":122
 *             """
 *             return "F2P1"
 *         if "F2PL" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F2PL: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F2PL, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 122, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":127
 *             take CausativeHr suffix, can take CausativeDHr suffix, can take ReciprocalHs suffix. e.g. Art, k
 *             """
 *             return "F2PL"             # <<<<<<<<<<<<<<
 *         if "F3P1" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F2PL);
    __pyx_r = __pyx_n_u_F2PL;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":122
 *             """
 *             return "F2P1"
 *         if "F2PL" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F2PL: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":128
 *             """
 *             return "F2PL"
 *         if "F3P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F3P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F3P1, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 128, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":133
 *             take PassiveHl suffix, can take CausativeHl suffix, can take ReciprocalHs suffix. e.g. Kok, sark
 *             """
 *             return "F3P1"             # <<<<<<<<<<<<<<
 *         if "F4P1" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F3P1);
    __pyx_r = __pyx_n_u_F3P1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":128
 *             """
 *             return "F2PL"
 *         if "F3P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F3P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":134
 *             """
 *             return "F3P1"
 *         if "F4P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix,
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F4P1, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 134, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":139
 *             can take CausativeT suffix, can take ReciprocalHs suffix. e.g. Anla
 *             """
 *             return "F4P1"             # <<<<<<<<<<<<<<
 *         if "F4PR" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F4P1);
    __pyx_r = __pyx_n_u_F4P1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":134
 *             """
 *             return "F3P1"
 *         if "F4P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix,
 */
  }

  /* "Dictionary/TxtWord.pyx":140
 *             """
 *             return "F4P1"
 *         if "F4PR" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PR: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F4PR, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 140, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":145
 *             take PassiveHl suffix, can take CausativeT suffix, can take ReciprocalHs suffix. e.g. Bitir, ar
 *             """
 *             return "F4PR"             # <<<<<<<<<<<<<<
 *         if "F4PL" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F4PR);
    __pyx_r = __pyx_n_u_F4PR;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":140
 *             """
 *             return "F4P1"
 *         if "F4PR" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PR: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":146
 *             """
 *             return "F4PR"
 *         if "F4PL" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PL: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F4PL, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 146, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":151
 *             take PassiveN suffix, can take CausativeT suffix, can take ReciprocalHs suffix. e.g. Bolal, mel
 *             """
 *             return "F4PL"             # <<<<<<<<<<<<<<
 *         if "F4PW" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F4PL);
    __pyx_r = __pyx_n_u_F4PL;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":146
 *             """
 *             return "F4PR"
 *         if "F4PL" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PL: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":152
 *             """
 *             return "F4PL"
 *         if "F4PW" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PW: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F4PW, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 152, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":157
 *             take PassiveN suffix, can take CausativeT suffix, can take ReciprocalHs suffix. e.g. Boyla, ala
 *             """
 *             return "F4PW"             # <<<<<<<<<<<<<<
 *         if "F5P1" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F4PW);
    __pyx_r = __pyx_n_u_F4PW;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":152
 *             """
 *             return "F4PL"
 *         if "F4PW" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F4PW: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":158
 *             """
 *             return "F4PW"
 *         if "F5P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F5P1, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 158, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":164
 *             suffix. e.g. Giy
 *             """
 *             return "F5P1"             # <<<<<<<<<<<<<<
 *         if "F5PL" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F5P1);
    __pyx_r = __pyx_n_u_F5P1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":158
 *             """
 *             return "F4PW"
 *         if "F5P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":165
 *             """
 *             return "F5P1"
 *         if "F5PL" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PL: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F5PL, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 165, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":170
 *             take PassiveHl suffix, can take CausativeDHr suffix, can take ReciprocalHs suffix. e.g. Bl, dal
 *             """
 *             return "F5PL"             # <<<<<<<<<<<<<<
 *         if "F5PR" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F5PL);
    __pyx_r = __pyx_n_u_F5PL;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":165
 *             """
 *             return "F5P1"
 *         if "F5PL" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PL: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix, can
 */
  }

  /* "Dictionary/TxtWord.pyx":171
 *             """
 *             return "F5PL"
 *         if "F5PR" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PR: The bare-form is a verb and depending on this attribute, the verb can take NominalVerb suffixes
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F5PR, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 171, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":177
 *             "-ymHs", can take AdjectiveRoot suffix, "-SH", can take Adjective suffix, "-Ar" e.g. Bilin, al
 *             """
 *             return "F5PR"             # <<<<<<<<<<<<<<
 *         if "F5PW" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F5PR);
    __pyx_r = __pyx_n_u_F5PR;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":171
 *             """
 *             return "F5PL"
 *         if "F5PR" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PR: The bare-form is a verb and depending on this attribute, the verb can take NominalVerb suffixes
 */
  }

  /* "Dictionary/TxtWord.pyx":178
 *             """
 *             return "F5PR"
 *         if "F5PW" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PW: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix,
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F5PW, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 178, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":183
 *             can take CausativeDHr suffix, can take ReciprocalHs suffix. e.g. Bover, cezbet
 *             """
 *             return "F5PW"             # <<<<<<<<<<<<<<
 *         if "F6P1" in self.__flags:
 *             """
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F5PW);
    __pyx_r = __pyx_n_u_F5PW;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":178
 *             """
 *             return "F5PR"
 *         if "F5PW" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F5PW: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix,
 */
  }

  /* "Dictionary/TxtWord.pyx":184
 *             """
 *             return "F5PW"
 *         if "F6P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F6P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix,
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F6P1, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 184, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "Dictionary/TxtWord.pyx":190
 *             ka
 *             """
 *             return "F6P1"             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_F6P1);
    __pyx_r = __pyx_n_u_F6P1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":184
 *             """
 *             return "F5PW"
 *         if "F6P1" in self.__flags:             # <<<<<<<<<<<<<<
 *             """
 *             F6P1: The bare-form is a verb and depending on this attribute, the verb can not take PassiveHn suffix,
 */
  }

  /* "Dictionary/TxtWord.pyx":191
 *             """
 *             return "F6P1"
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint samePos(self, TxtWord word):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u_);
  __pyx_r = __pyx_kp_u_;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":42
 *         self.__flags.remove(flag)
 * 
 *     cpdef str verbType(self):             # <<<<<<<<<<<<<<
 *         """
 *         The verbType method checks flags list and returns the corresponding cases.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.verbType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_7verbType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_6verbType[] = "\n        The verbType method checks flags list and returns the corresponding cases.\n\n        RETURNS\n        -------\n        str\n            the corresponding cases.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_7verbType(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("verbType (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_6verbType(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_6verbType(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("verbType", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_10Dictionary_7TxtWord_7TxtWord_verbType(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.verbType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":193
 *         return ""
 * 
 *     cpdef bint samePos(self, TxtWord word):             # <<<<<<<<<<<<<<
 *         """
 *         The samePos method takes TxtWord as input and returns true if;
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_9samePos(PyObject *__pyx_v_self, PyObject *__pyx_v_word); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_samePos(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_word, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("samePos", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_samePos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 193, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_9samePos)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_word)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_word));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 193, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 193, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":222
 *             true if given word is nominal, verb, adjective, pronoun or adverb, false otherwise.
 *         """
 *         if self.isNominal() and word.isNominal():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isVerb() and word.isVerb():
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->isNominal(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_word->__pyx_base.__pyx_vtab)->isNominal(__pyx_v_word, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":223
 *         """
 *         if self.isNominal() and word.isNominal():
 *             return True             # <<<<<<<<<<<<<<
 *         if self.isVerb() and word.isVerb():
 *             return True
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":222
 *             true if given word is nominal, verb, adjective, pronoun or adverb, false otherwise.
 *         """
 *         if self.isNominal() and word.isNominal():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isVerb() and word.isVerb():
 */
  }

  /* "Dictionary/TxtWord.pyx":224
 *         if self.isNominal() and word.isNominal():
 *             return True
 *         if self.isVerb() and word.isVerb():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isAdjective() and word.isAdjective():
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->isVerb(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_word->__pyx_base.__pyx_vtab)->isVerb(__pyx_v_word, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":225
 *             return True
 *         if self.isVerb() and word.isVerb():
 *             return True             # <<<<<<<<<<<<<<
 *         if self.isAdjective() and word.isAdjective():
 *             return True
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":224
 *         if self.isNominal() and word.isNominal():
 *             return True
 *         if self.isVerb() and word.isVerb():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isAdjective() and word.isAdjective():
 */
  }

  /* "Dictionary/TxtWord.pyx":226
 *         if self.isVerb() and word.isVerb():
 *             return True
 *         if self.isAdjective() and word.isAdjective():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isPronoun() and word.isPronoun():
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->isAdjective(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_word->__pyx_base.__pyx_vtab)->isAdjective(__pyx_v_word, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":227
 *             return True
 *         if self.isAdjective() and word.isAdjective():
 *             return True             # <<<<<<<<<<<<<<
 *         if self.isPronoun() and word.isPronoun():
 *             return True
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":226
 *         if self.isVerb() and word.isVerb():
 *             return True
 *         if self.isAdjective() and word.isAdjective():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isPronoun() and word.isPronoun():
 */
  }

  /* "Dictionary/TxtWord.pyx":228
 *         if self.isAdjective() and word.isAdjective():
 *             return True
 *         if self.isPronoun() and word.isPronoun():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isAdverb() and word.isAdverb():
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->isPronoun(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_word->__pyx_base.__pyx_vtab)->isPronoun(__pyx_v_word, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L13_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":229
 *             return True
 *         if self.isPronoun() and word.isPronoun():
 *             return True             # <<<<<<<<<<<<<<
 *         if self.isAdverb() and word.isAdverb():
 *             return True
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":228
 *         if self.isAdjective() and word.isAdjective():
 *             return True
 *         if self.isPronoun() and word.isPronoun():             # <<<<<<<<<<<<<<
 *             return True
 *         if self.isAdverb() and word.isAdverb():
 */
  }

  /* "Dictionary/TxtWord.pyx":230
 *         if self.isPronoun() and word.isPronoun():
 *             return True
 *         if self.isAdverb() and word.isAdverb():             # <<<<<<<<<<<<<<
 *             return True
 *         return False
 */
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self->__pyx_base.__pyx_vtab)->isAdverb(__pyx_v_self, 0) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_6 = (((struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord *)__pyx_v_word->__pyx_base.__pyx_vtab)->isAdverb(__pyx_v_word, 0) != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L16_bool_binop_done:;
  if (__pyx_t_5) {

    /* "Dictionary/TxtWord.pyx":231
 *             return True
 *         if self.isAdverb() and word.isAdverb():
 *             return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "Dictionary/TxtWord.pyx":230
 *         if self.isPronoun() and word.isPronoun():
 *             return True
 *         if self.isAdverb() and word.isAdverb():             # <<<<<<<<<<<<<<
 *             return True
 *         return False
 */
  }

  /* "Dictionary/TxtWord.pyx":232
 *         if self.isAdverb() and word.isAdverb():
 *             return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isNominal(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":193
 *         return ""
 * 
 *     cpdef bint samePos(self, TxtWord word):             # <<<<<<<<<<<<<<
 *         """
 *         The samePos method takes TxtWord as input and returns true if;
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.samePos", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_9samePos(PyObject *__pyx_v_self, PyObject *__pyx_v_word); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_8samePos[] = "\n        The samePos method takes TxtWord as input and returns true if;\n\n        flags list contains CL_ISIM\n        CL_ISIM: The bare-form of the word is a noun. e.g. Abla\n\n        flags list contains CL_FIIL\n        CL_FIIL: The bare-form of the word is a verb. e.g. Affet\n\n        flags list contains IS_ADJ\n        IS_ADJ: The bare-form of the word is a adjective. e.g. Acayip\n\n        flags list contains IS_ZM\n        IS_ZM: The bare-form of the word is a pronoun. e.g. Ba\305\237kas\304\261\n\n        flags list contains IS_ADVERB\n        IS_ADVERB: The bare-form of the word is a adverb. e.g. Tekrar, a\303\247\304\261ktan, adeta\n\n        PARAMETERS\n        ----------\n        word : TxtWord\n            TxtWord type input.\n\n        RETURNS\n        -------\n        bool\n            true if given word is nominal, verb, adjective, pronoun or adverb, false otherwise.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_9samePos(PyObject *__pyx_v_self, PyObject *__pyx_v_word) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("samePos (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_word), __pyx_ptype_10Dictionary_7TxtWord_TxtWord, 1, "word", 0))) __PYX_ERR(0, 193, __pyx_L1_error)
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_8samePos(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self), ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_word));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_8samePos(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_word) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("samePos", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_samePos(__pyx_v_self, __pyx_v_word, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.samePos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":234
 *         return False
 * 
 *     cpdef bint isNominal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNominal method returns true if flags list contains CL_ISIM.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_11isNominal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isNominal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNominal", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isNominal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_11isNominal)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 234, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 234, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":243
 *             true if flags list contains CL_ISIM.
 *         """
 *         return "CL_ISIM" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPassive(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_CL_ISIM, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 243, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":234
 *         return False
 * 
 *     cpdef bint isNominal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNominal method returns true if flags list contains CL_ISIM.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isNominal", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_11isNominal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_10isNominal[] = "\n        The isNominal method returns true if flags list contains CL_ISIM.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains CL_ISIM.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_11isNominal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isNominal (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_10isNominal(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_10isNominal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNominal", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isNominal(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isNominal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":245
 *         return "CL_ISIM" in self.__flags
 * 
 *     cpdef bint isPassive(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPassive method returns true if flags list contains PASSIVE-HN.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_13isPassive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPassive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPassive", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPassive); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_13isPassive)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 245, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":254
 *             true if flags list contains PASSIVE-HN.
 *         """
 *         return "PASSIVE-HN" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isAbbreviation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_PASSIVE_HN, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 254, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":245
 *         return "CL_ISIM" in self.__flags
 * 
 *     cpdef bint isPassive(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPassive method returns true if flags list contains PASSIVE-HN.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPassive", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_13isPassive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_12isPassive[] = "\n        The isPassive method returns true if flags list contains PASSIVE-HN.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains PASSIVE-HN.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_13isPassive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPassive (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_12isPassive(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_12isPassive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPassive", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPassive(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPassive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":256
 *         return "PASSIVE-HN" in self.__flags
 * 
 *     cpdef bint isAbbreviation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAbbreviation method returns true if flags list contains IS_KIS.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_15isAbbreviation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isAbbreviation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAbbreviation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isAbbreviation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_15isAbbreviation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 256, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 256, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":265
 *             true if flags list contains IS_KIS.
 *         """
 *         return "IS_KIS" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isInterjection(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_KIS, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 265, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":256
 *         return "PASSIVE-HN" in self.__flags
 * 
 *     cpdef bint isAbbreviation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAbbreviation method returns true if flags list contains IS_KIS.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isAbbreviation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_15isAbbreviation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_14isAbbreviation[] = "\n        The isAbbreviation method returns true if flags list contains IS_KIS.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_KIS.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_15isAbbreviation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isAbbreviation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_14isAbbreviation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_14isAbbreviation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAbbreviation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isAbbreviation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isAbbreviation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":267
 *         return "IS_KIS" in self.__flags
 * 
 *     cpdef bint isInterjection(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isInterjection method returns true if flags list contains IS_INTERJ.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_17isInterjection(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isInterjection(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isInterjection", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isInterjection); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_17isInterjection)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 267, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":276
 *             true if flags list contains IS_INTERJ.
 *         """
 *         return "IS_INTERJ" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isDuplicate(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_INTERJ, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 276, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":267
 *         return "IS_KIS" in self.__flags
 * 
 *     cpdef bint isInterjection(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isInterjection method returns true if flags list contains IS_INTERJ.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isInterjection", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_17isInterjection(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_16isInterjection[] = "\n        The isInterjection method returns true if flags list contains IS_INTERJ.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_INTERJ.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_17isInterjection(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isInterjection (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_16isInterjection(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_16isInterjection(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isInterjection", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isInterjection(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isInterjection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":278
 *         return "IS_INTERJ" in self.__flags
 * 
 *     cpdef bint isDuplicate(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDuplicate method returns true if flags list contains IS_DUP.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_19isDuplicate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isDuplicate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDuplicate", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isDuplicate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_19isDuplicate)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 278, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 278, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":287
 *             true if flags list contains IS_DUP.
 *         """
 *         return "IS_DUP" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isHeader(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_DUP, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 287, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":278
 *         return "IS_INTERJ" in self.__flags
 * 
 *     cpdef bint isDuplicate(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDuplicate method returns true if flags list contains IS_DUP.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isDuplicate", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_19isDuplicate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_18isDuplicate[] = "\n        The isDuplicate method returns true if flags list contains IS_DUP.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_DUP.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_19isDuplicate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isDuplicate (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_18isDuplicate(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_18isDuplicate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDuplicate", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isDuplicate(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isDuplicate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":289
 *         return "IS_DUP" in self.__flags
 * 
 *     cpdef bint isHeader(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isHeader method returns true if flags list contains IS_HEADER.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_21isHeader(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isHeader(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isHeader", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isHeader); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_21isHeader)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 289, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 289, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":298
 *             true if flags list contains IS_HEADER.
 *         """
 *         return "IS_HEADER" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isAdjective(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_HEADER, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 298, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":289
 *         return "IS_DUP" in self.__flags
 * 
 *     cpdef bint isHeader(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isHeader method returns true if flags list contains IS_HEADER.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isHeader", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_21isHeader(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_20isHeader[] = "\n        The isHeader method returns true if flags list contains IS_HEADER.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_HEADER.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_21isHeader(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isHeader (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_20isHeader(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_20isHeader(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isHeader", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isHeader(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isHeader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":300
 *         return "IS_HEADER" in self.__flags
 * 
 *     cpdef bint isAdjective(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAdjective method returns true if flags list contains IS_ADJ.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_23isAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAdjective", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isAdjective); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_23isAdjective)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 300, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":309
 *             true if flags list contains IS_ADJ.
 *         """
 *         return "IS_ADJ" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPureAdjective(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_ADJ, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 309, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":300
 *         return "IS_HEADER" in self.__flags
 * 
 *     cpdef bint isAdjective(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAdjective method returns true if flags list contains IS_ADJ.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isAdjective", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_23isAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_22isAdjective[] = "\n        The isAdjective method returns true if flags list contains IS_ADJ.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_ADJ.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_23isAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isAdjective (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_22isAdjective(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_22isAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAdjective", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdjective(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isAdjective", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":311
 *         return "IS_ADJ" in self.__flags
 * 
 *     cpdef bint isPureAdjective(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPureAdjective method returns true if flags list contains IS_PUREADJ.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_25isPureAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPureAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPureAdjective", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPureAdjective); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_25isPureAdjective)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 311, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 311, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":320
 *             true if flags list contains IS_PUREADJ.
 *         """
 *         return "IS_PUREADJ" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPronoun(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_PUREADJ, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 320, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":311
 *         return "IS_ADJ" in self.__flags
 * 
 *     cpdef bint isPureAdjective(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPureAdjective method returns true if flags list contains IS_PUREADJ.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPureAdjective", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_25isPureAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_24isPureAdjective[] = "\n        The isPureAdjective method returns true if flags list contains IS_PUREADJ.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_PUREADJ.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_25isPureAdjective(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPureAdjective (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_24isPureAdjective(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_24isPureAdjective(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPureAdjective", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPureAdjective(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPureAdjective", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":322
 *         return "IS_PUREADJ" in self.__flags
 * 
 *     cpdef bint isPronoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPronoun method returns true if flags list contains IS_ZM.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_27isPronoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPronoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPronoun", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPronoun); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 322, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_27isPronoun)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 322, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 322, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":332
 *             true if flags list contains IS_ZM.
 *         """
 *         return "IS_ZM" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isQuestion(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_ZM, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 332, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":322
 *         return "IS_PUREADJ" in self.__flags
 * 
 *     cpdef bint isPronoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPronoun method returns true if flags list contains IS_ZM.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPronoun", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_27isPronoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_26isPronoun[] = "\n        The isPronoun method returns true if flags list contains IS_ZM.\n        IS_ZM: The bare-form of the word is a pronoun. e.g. Hangi, hep, hi\303\247biri\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_ZM.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_27isPronoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPronoun (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_26isPronoun(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_26isPronoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPronoun", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPronoun(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPronoun", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":334
 *         return "IS_ZM" in self.__flags
 * 
 *     cpdef bint isQuestion(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isQuestion method returns true if flags list contains IS_QUES.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_29isQuestion(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isQuestion(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isQuestion", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isQuestion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_29isQuestion)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 334, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":344
 *             true if flags list contains IS_QUES.
 *         """
 *         return "IS_QUES" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isVerb(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_QUES, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 344, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":334
 *         return "IS_ZM" in self.__flags
 * 
 *     cpdef bint isQuestion(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isQuestion method returns true if flags list contains IS_QUES.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isQuestion", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_29isQuestion(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_28isQuestion[] = "\n        The isQuestion method returns true if flags list contains IS_QUES.\n        IS_QUES: The bare-form of the word is a question. e.g. Mi, mu, m\303\274\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_QUES.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_29isQuestion(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isQuestion (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_28isQuestion(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_28isQuestion(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isQuestion", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isQuestion(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isQuestion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":346
 *         return "IS_QUES" in self.__flags
 * 
 *     cpdef bint isVerb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isVerb method returns true if flags list contains CL_FIIL.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_31isVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isVerb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isVerb", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isVerb); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 346, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_31isVerb)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 346, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 346, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":355
 *             true if flags list contains CL_FIIL.
 *         """
 *         return "CL_FIIL" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPortmanteau(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_CL_FIIL, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 355, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":346
 *         return "IS_QUES" in self.__flags
 * 
 *     cpdef bint isVerb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isVerb method returns true if flags list contains CL_FIIL.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isVerb", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_31isVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_30isVerb[] = "\n        The isVerb method returns true if flags list contains CL_FIIL.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains CL_FIIL.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_31isVerb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isVerb (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_30isVerb(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_30isVerb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isVerb", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isVerb(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isVerb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":357
 *         return "CL_FIIL" in self.__flags
 * 
 *     cpdef bint isPortmanteau(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteau method returns true if flags list contains IS_BILE.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_33isPortmanteau(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteau(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteau", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPortmanteau); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_33isPortmanteau)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 357, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 357, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":367
 *             true if flags list contains IS_BILE.
 *         """
 *         return "IS_BILE" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isDeterminer(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_BILE, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 367, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":357
 *         return "CL_FIIL" in self.__flags
 * 
 *     cpdef bint isPortmanteau(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteau method returns true if flags list contains IS_BILE.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPortmanteau", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_33isPortmanteau(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_32isPortmanteau[] = "\n        The isPortmanteau method returns true if flags list contains IS_BILE\305\236.\n        IS_BILE\305\236: The bare-form is a portmanteau word in affixed form. e.g. gelin\303\247i\303\247e\304\237i\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_BILE\305\236.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_33isPortmanteau(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPortmanteau (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_32isPortmanteau(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_32isPortmanteau(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteau", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteau(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPortmanteau", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":369
 *         return "IS_BILE" in self.__flags
 * 
 *     cpdef bint isDeterminer(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDeterminer method returns true if flags list contains IS_DET.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_35isDeterminer(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isDeterminer(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDeterminer", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isDeterminer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 369, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_35isDeterminer)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 369, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":379
 *             true if flags list contains IS_DET.
 *         """
 *         return "IS_DET" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isConjunction(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_DET, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 379, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":369
 *         return "IS_BILE" in self.__flags
 * 
 *     cpdef bint isDeterminer(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDeterminer method returns true if flags list contains IS_DET.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isDeterminer", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_35isDeterminer(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_34isDeterminer[] = "\n        The isDeterminer method returns true if flags list contains IS_DET.\n        IS_DET: The bare-form of the word is a determiner. e.g. Baz\304\261, bir\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_DET.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_35isDeterminer(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isDeterminer (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_34isDeterminer(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_34isDeterminer(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDeterminer", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isDeterminer(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isDeterminer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":381
 *         return "IS_DET" in self.__flags
 * 
 *     cpdef bint isConjunction(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isConjunction method returns true if flags list contains IS_CONJ.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_37isConjunction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isConjunction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isConjunction", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isConjunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_37isConjunction)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 381, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 381, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":391
 *             true if flags list contains IS_CONJ.
 *         """
 *         return "IS_CONJ" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isAdverb(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_CONJ, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 391, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":381
 *         return "IS_DET" in self.__flags
 * 
 *     cpdef bint isConjunction(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isConjunction method returns true if flags list contains IS_CONJ.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isConjunction", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_37isConjunction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_36isConjunction[] = "\n        The isConjunction method returns true if flags list contains IS_CONJ.\n        IS_CONJ: The bare-form of the word is a conjunction. e.g. Gerek, halbuki\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_CONJ.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_37isConjunction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isConjunction (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_36isConjunction(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_36isConjunction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isConjunction", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isConjunction(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isConjunction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":393
 *         return "IS_CONJ" in self.__flags
 * 
 *     cpdef bint isAdverb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAdverb method returns true if flags list contains IS_ADVERB.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_39isAdverb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdverb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAdverb", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isAdverb); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_39isAdverb)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 393, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":402
 *             true if flags list contains IS_ADVERB.
 *         """
 *         return "IS_ADVERB" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPostP(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_ADVERB, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 402, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":393
 *         return "IS_CONJ" in self.__flags
 * 
 *     cpdef bint isAdverb(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isAdverb method returns true if flags list contains IS_ADVERB.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isAdverb", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_39isAdverb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_38isAdverb[] = "\n        The isAdverb method returns true if flags list contains IS_ADVERB.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_ADVERB.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_39isAdverb(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isAdverb (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_38isAdverb(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_38isAdverb(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isAdverb", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdverb(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isAdverb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":404
 *         return "IS_ADVERB" in self.__flags
 * 
 *     cpdef bint isPostP(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPostP method returns true if flags list contains IS_POSTP.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_41isPostP(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPostP(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPostP", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPostP); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_41isPostP)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 404, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":414
 *             true if flags list contains IS_POSTP.
 *         """
 *         return "IS_POSTP" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPortmanteauEndingWithSI(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_POSTP, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 414, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":404
 *         return "IS_ADVERB" in self.__flags
 * 
 *     cpdef bint isPostP(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPostP method returns true if flags list contains IS_POSTP.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPostP", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_41isPostP(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_40isPostP[] = "\n        The isPostP method returns true if flags list contains IS_POSTP.\n        IS_POSTP: The bare-form of the word is a postposition. e.g. \303\226nce, takdirde, \303\274zere\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_POSTP.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_41isPostP(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPostP (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_40isPostP(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_40isPostP(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPostP", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPostP(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPostP", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":416
 *         return "IS_POSTP" in self.__flags
 * 
 *     cpdef bint isPortmanteauEndingWithSI(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteauEndingWithSI method returns true if flags list contains IS_B_SI.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_43isPortmanteauEndingWithSI(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauEndingWithSI(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteauEndingWithSI", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPortmanteauEndingWithSI); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_43isPortmanteauEndingWithSI)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 416, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":426
 *             true if flags list contains IS_B_SI.
 *         """
 *         return "IS_B_SI" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPortmanteauFacedVowelEllipsis(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_B_SI, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 426, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":416
 *         return "IS_POSTP" in self.__flags
 * 
 *     cpdef bint isPortmanteauEndingWithSI(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteauEndingWithSI method returns true if flags list contains IS_B_SI.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPortmanteauEndingWithSI", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_43isPortmanteauEndingWithSI(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_42isPortmanteauEndingWithSI[] = "\n        The isPortmanteauEndingWithSI method returns true if flags list contains IS_B_SI.\n        IS_B_SI: The bare-form is a portmanteau word ending with \"s\304\261\". e.g. Giritlalesi\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_B_SI.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_43isPortmanteauEndingWithSI(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPortmanteauEndingWithSI (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_42isPortmanteauEndingWithSI(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_42isPortmanteauEndingWithSI(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteauEndingWithSI", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauEndingWithSI(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPortmanteauEndingWithSI", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":428
 *         return "IS_B_SI" in self.__flags
 * 
 *     cpdef bint isPortmanteauFacedVowelEllipsis(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteauFacedVowelEllipsis method returns true if flags list contains IS_B_UD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_45isPortmanteauFacedVowelEllipsis(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedVowelEllipsis(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteauFacedVowelEllipsis", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPortmanteauFacedVowelEllipsis); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_45isPortmanteauFacedVowelEllipsis)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 428, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 428, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":439
 *             true if flags list contains IS_B_UD.
 *         """
 *         return "IS_B_UD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPortmanteauFacedSoftening(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_B_UD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 439, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":428
 *         return "IS_B_SI" in self.__flags
 * 
 *     cpdef bint isPortmanteauFacedVowelEllipsis(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteauFacedVowelEllipsis method returns true if flags list contains IS_B_UD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPortmanteauFacedVowelEllipsis", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_45isPortmanteauFacedVowelEllipsis(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_44isPortmanteauFacedVowelEllipsis[] = "\n        The isPortmanteauFacedVowelEllipsis method returns true if flags list contains IS_B_UD.\n        IS_B_UD: The bare-form of the word includes vowel epenthesis,\n        therefore the last inserted vowel drops during suffixation. e.g. \304\260nsano\304\237lu\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_B_UD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_45isPortmanteauFacedVowelEllipsis(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPortmanteauFacedVowelEllipsis (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_44isPortmanteauFacedVowelEllipsis(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_44isPortmanteauFacedVowelEllipsis(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteauFacedVowelEllipsis", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedVowelEllipsis(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPortmanteauFacedVowelEllipsis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":441
 *         return "IS_B_UD" in self.__flags
 * 
 *     cpdef bint isPortmanteauFacedSoftening(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteauFacedSoftening method returns true if flags list contains IS_B_SD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_47isPortmanteauFacedSoftening(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedSoftening(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteauFacedSoftening", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPortmanteauFacedSoftening); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_47isPortmanteauFacedSoftening)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 441, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 441, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":451
 *             true if flags list contains IS_B_SD.
 *         """
 *         return "IS_B_SD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isSuffix(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_B_SD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 451, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":441
 *         return "IS_B_UD" in self.__flags
 * 
 *     cpdef bint isPortmanteauFacedSoftening(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPortmanteauFacedSoftening method returns true if flags list contains IS_B_SD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPortmanteauFacedSoftening", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_47isPortmanteauFacedSoftening(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_46isPortmanteauFacedSoftening[] = "\n        The isPortmanteauFacedSoftening method returns true if flags list contains IS_B_SD.\n        IS_B_SD: The bare-form of the word includes softening. e.g. \303\207an\303\247i\303\247e\304\237i\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_B_SD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_47isPortmanteauFacedSoftening(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPortmanteauFacedSoftening (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_46isPortmanteauFacedSoftening(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_46isPortmanteauFacedSoftening(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPortmanteauFacedSoftening", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedSoftening(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPortmanteauFacedSoftening", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":453
 *         return "IS_B_SD" in self.__flags
 * 
 *     cpdef bint isSuffix(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isSuffix method returns true if flags list contains EK.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_49isSuffix(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isSuffix(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isSuffix", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isSuffix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_49isSuffix)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 453, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":463
 *             true if flags list contains EK.
 *         """
 *         return "EK" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isProperNoun(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_EK, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 463, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":453
 *         return "IS_B_SD" in self.__flags
 * 
 *     cpdef bint isSuffix(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isSuffix method returns true if flags list contains EK.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isSuffix", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_49isSuffix(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_48isSuffix[] = "\n        The isSuffix method returns true if flags list contains EK.\n        EK: This tag indicates complementary verbs. e.g. \304\260di, iken, imi\305\237.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains EK.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_49isSuffix(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isSuffix (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_48isSuffix(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_48isSuffix(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isSuffix", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isSuffix(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isSuffix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":465
 *         return "EK" in self.__flags
 * 
 *     cpdef bint isProperNoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isProperNoun method returns true if flags list contains IS_OA.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_51isProperNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isProperNoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isProperNoun", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isProperNoun); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_51isProperNoun)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 465, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 465, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":475
 *             true if flags list contains IS_OA.
 *         """
 *         return "IS_OA" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPlural(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_OA, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 475, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":465
 *         return "EK" in self.__flags
 * 
 *     cpdef bint isProperNoun(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isProperNoun method returns true if flags list contains IS_OA.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isProperNoun", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_51isProperNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_50isProperNoun[] = "\n        The isProperNoun method returns true if flags list contains IS_OA.\n        IS_OA: The bare-form of the word is a proper noun. e.g. Abant, Be\305\237ikta\305\237\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_OA.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_51isProperNoun(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isProperNoun (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_50isProperNoun(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_50isProperNoun(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isProperNoun", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isProperNoun(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isProperNoun", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":477
 *         return "IS_OA" in self.__flags
 * 
 *     cpdef bint isPlural(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPlural method returns true if flags list contains IS_CA.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_53isPlural(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPlural(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPlural", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPlural); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_53isPlural)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 477, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 477, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":488
 *             true if flags list contains IS_CA.
 *         """
 *         return "IS_CA" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isNumeral(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_CA, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 488, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":477
 *         return "IS_OA" in self.__flags
 * 
 *     cpdef bint isPlural(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPlural method returns true if flags list contains IS_CA.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPlural", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_53isPlural(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_52isPlural[] = "\n        The isPlural method returns true if flags list contains IS_CA.\n        IS_CA: The bare-form of the word is already in a plural form,\n        therefore can not take plural suffixes such as \"ler\" or \"lar\". e.g. Bu\304\237daygiller\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_CA.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_53isPlural(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPlural (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_52isPlural(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_52isPlural(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPlural", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPlural(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPlural", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":490
 *         return "IS_CA" in self.__flags
 * 
 *     cpdef bint isNumeral(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNumeral method returns true if flags list contains IS_SAYI.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_55isNumeral(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isNumeral(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNumeral", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isNumeral); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 490, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_55isNumeral)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 490, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":500
 *             true if flags list contains IS_SAYI.
 *         """
 *         return "IS_SAYI" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isReal(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_SAYI, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 500, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":490
 *         return "IS_CA" in self.__flags
 * 
 *     cpdef bint isNumeral(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isNumeral method returns true if flags list contains IS_SAYI.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isNumeral", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_55isNumeral(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_54isNumeral[] = "\n        The isNumeral method returns true if flags list contains IS_SAYI.\n        IS_SAYI: The word is a number. e.g. D\303\266rt\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_SAYI.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_55isNumeral(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isNumeral (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_54isNumeral(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_54isNumeral(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isNumeral", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isNumeral(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isNumeral", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":502
 *         return "IS_SAYI" in self.__flags
 * 
 *     cpdef bint isReal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isReal method returns true if flags list contains IS_REELSAYI.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_57isReal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isReal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isReal", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isReal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_57isReal)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 502, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":511
 *             true if flags list contains IS_REELSAYI.
 *         """
 *         return "IS_REELSAYI" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isFraction(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_REELSAYI, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 511, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":502
 *         return "IS_SAYI" in self.__flags
 * 
 *     cpdef bint isReal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isReal method returns true if flags list contains IS_REELSAYI.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isReal", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_57isReal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_56isReal[] = "\n        The isReal method returns true if flags list contains IS_REELSAYI.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_REELSAYI.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_57isReal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isReal (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_56isReal(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_56isReal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isReal", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isReal(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isReal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":513
 *         return "IS_REELSAYI" in self.__flags
 * 
 *     cpdef bint isFraction(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isFraction method returns true if flags list contains IS_KESIR.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_59isFraction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isFraction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isFraction", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isFraction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_59isFraction)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 513, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 513, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":522
 *             true if flags list contains IS_KESIR.
 *         """
 *         return "IS_KESIR" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isTime(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_KESIR, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 522, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":513
 *         return "IS_REELSAYI" in self.__flags
 * 
 *     cpdef bint isFraction(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isFraction method returns true if flags list contains IS_KESIR.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isFraction", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_59isFraction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_58isFraction[] = "\n        The isFraction method returns true if flags list contains IS_KESIR.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_KESIR.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_59isFraction(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isFraction (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_58isFraction(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_58isFraction(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isFraction", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isFraction(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isFraction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":524
 *         return "IS_KESIR" in self.__flags
 * 
 *     cpdef bint isTime(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isTime method returns true if flags list contains IS_ZAMAN.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_61isTime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isTime(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isTime", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isTime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_61isTime)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 524, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 524, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":533
 *             true if flags list contains IS_ZAMAN.
 *         """
 *         return "IS_ZAMAN" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isDate(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_ZAMAN, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 533, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":524
 *         return "IS_KESIR" in self.__flags
 * 
 *     cpdef bint isTime(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isTime method returns true if flags list contains IS_ZAMAN.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isTime", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_61isTime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_60isTime[] = "\n        The isTime method returns true if flags list contains IS_ZAMAN.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_ZAMAN.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_61isTime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isTime (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_60isTime(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_60isTime(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isTime", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isTime(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isTime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":535
 *         return "IS_ZAMAN" in self.__flags
 * 
 *     cpdef bint isDate(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDate method returns true if flags list contains IS_DATE.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_63isDate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isDate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDate", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isDate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_63isDate)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 535, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":544
 *             true if flags list contains IS_DATE.
 *         """
 *         return "IS_DATE" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isPercent(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_DATE, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 544, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":535
 *         return "IS_ZAMAN" in self.__flags
 * 
 *     cpdef bint isDate(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isDate method returns true if flags list contains IS_DATE.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isDate", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_63isDate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_62isDate[] = "\n        The isDate method returns true if flags list contains IS_DATE.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_DATE.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_63isDate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isDate (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_62isDate(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_62isDate(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isDate", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isDate(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":546
 *         return "IS_DATE" in self.__flags
 * 
 *     cpdef bint isPercent(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPercent method returns true if flags list contains IS_PERCENT.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_65isPercent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isPercent(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPercent", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isPercent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_65isPercent)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 546, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 546, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":555
 *             true if flags list contains IS_PERCENT.
 *         """
 *         return "IS_PERCENT" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isRange(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_PERCENT, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 555, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":546
 *         return "IS_DATE" in self.__flags
 * 
 *     cpdef bint isPercent(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isPercent method returns true if flags list contains IS_PERCENT.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isPercent", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_65isPercent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_64isPercent[] = "\n        The isPercent method returns true if flags list contains IS_PERCENT.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_PERCENT.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_65isPercent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPercent (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_64isPercent(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_64isPercent(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPercent", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPercent(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isPercent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":557
 *         return "IS_PERCENT" in self.__flags
 * 
 *     cpdef bint isRange(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isRange method returns true if flags list contains IS_RANGE.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_67isRange(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isRange(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRange", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isRange); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_67isRange)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 557, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":566
 *             true if flags list contains IS_RANGE.
 *         """
 *         return "IS_RANGE" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isOrdinal(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_RANGE, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 566, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":557
 *         return "IS_PERCENT" in self.__flags
 * 
 *     cpdef bint isRange(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isRange method returns true if flags list contains IS_RANGE.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isRange", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_67isRange(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_66isRange[] = "\n        The isRange method returns true if flags list contains IS_RANGE.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_RANGE.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_67isRange(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isRange (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_66isRange(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_66isRange(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRange", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isRange(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isRange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":568
 *         return "IS_RANGE" in self.__flags
 * 
 *     cpdef bint isOrdinal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isOrdinal method returns true if flags list contains IS_ORD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_69isOrdinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isOrdinal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isOrdinal", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isOrdinal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_69isOrdinal)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":578
 *             true if flags list contains IS_ORD.
 *         """
 *         return "IS_ORD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint notObeysVowelHarmonyDuringAgglutination(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_ORD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 578, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":568
 *         return "IS_RANGE" in self.__flags
 * 
 *     cpdef bint isOrdinal(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isOrdinal method returns true if flags list contains IS_ORD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isOrdinal", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_69isOrdinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_68isOrdinal[] = "\n        The isOrdinal method returns true if flags list contains IS_ORD.\n        IS_ORD: The bare-form of the word can take suffixes and these suffixes define a ranking. e.g. Birinci\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_ORD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_69isOrdinal(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isOrdinal (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_68isOrdinal(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_68isOrdinal(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isOrdinal", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isOrdinal(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isOrdinal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":580
 *         return "IS_ORD" in self.__flags
 * 
 *     cpdef bint notObeysVowelHarmonyDuringAgglutination(self):             # <<<<<<<<<<<<<<
 *         """
 *         The notObeysVowelHarmonyDuringAgglutination method returns true if flags list contains IS_UU.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_71notObeysVowelHarmonyDuringAgglutination(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_notObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("notObeysVowelHarmonyDuringAgglutination", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_notObeysVowelHarmonyDuringAgglut); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_71notObeysVowelHarmonyDuringAgglutination)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 580, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 580, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":590
 *             true if flags list contains IS_UU.
 *         """
 *         return "IS_UU" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint obeysAndNotObeysVowelHarmonyDuringAgglutination(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_UU, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 590, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":580
 *         return "IS_ORD" in self.__flags
 * 
 *     cpdef bint notObeysVowelHarmonyDuringAgglutination(self):             # <<<<<<<<<<<<<<
 *         """
 *         The notObeysVowelHarmonyDuringAgglutination method returns true if flags list contains IS_UU.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.notObeysVowelHarmonyDuringAgglutination", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_71notObeysVowelHarmonyDuringAgglutination(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_70notObeysVowelHarmonyDuringAgglutination[] = "\n        The notObeysVowelHarmonyDuringAgglutination method returns true if flags list contains IS_UU.\n        IS_UU: The bare-form does not obey vowel harmony while taking suffixes. e.g. Dikkat\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_UU.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_71notObeysVowelHarmonyDuringAgglutination(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("notObeysVowelHarmonyDuringAgglutination (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_70notObeysVowelHarmonyDuringAgglutination(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_70notObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("notObeysVowelHarmonyDuringAgglutination", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_notObeysVowelHarmonyDuringAgglutination(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.notObeysVowelHarmonyDuringAgglutination", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":592
 *         return "IS_UU" in self.__flags
 * 
 *     cpdef bint obeysAndNotObeysVowelHarmonyDuringAgglutination(self):             # <<<<<<<<<<<<<<
 *         """
 *         The obeysAndNotObeysVowelHarmonyDuringAgglutination method returns true if flags list contains IS_UUU.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_73obeysAndNotObeysVowelHarmonyDuringAgglutination(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_obeysAndNotObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("obeysAndNotObeysVowelHarmonyDuringAgglutination", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_obeysAndNotObeysVowelHarmonyDuri); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_73obeysAndNotObeysVowelHarmonyDuringAgglutination)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 592, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 592, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":602
 *             true if flags list contains IS_UUU.
 *         """
 *         return "IS_UUU" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint rootSoftenDuringSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_UUU, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 602, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":592
 *         return "IS_UU" in self.__flags
 * 
 *     cpdef bint obeysAndNotObeysVowelHarmonyDuringAgglutination(self):             # <<<<<<<<<<<<<<
 *         """
 *         The obeysAndNotObeysVowelHarmonyDuringAgglutination method returns true if flags list contains IS_UUU.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.obeysAndNotObeysVowelHarmonyDuringAgglutination", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_73obeysAndNotObeysVowelHarmonyDuringAgglutination(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_72obeysAndNotObeysVowelHarmonyDuringAgglutination[] = "\n        The obeysAndNotObeysVowelHarmonyDuringAgglutination method returns true if flags list contains IS_UUU.\n        IS_UUU: The bare-form does not obey vowel harmony while taking suffixes. e.g. Bol, kalp\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_UUU.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_73obeysAndNotObeysVowelHarmonyDuringAgglutination(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("obeysAndNotObeysVowelHarmonyDuringAgglutination (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_72obeysAndNotObeysVowelHarmonyDuringAgglutination(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_72obeysAndNotObeysVowelHarmonyDuringAgglutination(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("obeysAndNotObeysVowelHarmonyDuringAgglutination", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_obeysAndNotObeysVowelHarmonyDuringAgglutination(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.obeysAndNotObeysVowelHarmonyDuringAgglutination", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":604
 *         return "IS_UUU" in self.__flags
 * 
 *     cpdef bint rootSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The rootSoftenDuringSuffixation method returns true if flags list contains IS_SD, F_SD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_75rootSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rootSoftenDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rootSoftenDuringSuffixation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_75rootSoftenDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 604, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":613
 *             true if flags list contains IS_SD, F_SD.
 *         """
 *         return "IS_SD" in self.__flags or "F_SD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint rootSoftenAndNotSoftenDuringSuffixation(self):
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_SD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 613, __pyx_L1_error)
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F_SD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 613, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 != 0);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":604
 *         return "IS_UUU" in self.__flags
 * 
 *     cpdef bint rootSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The rootSoftenDuringSuffixation method returns true if flags list contains IS_SD, F_SD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.rootSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_75rootSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_74rootSoftenDuringSuffixation[] = "\n        The rootSoftenDuringSuffixation method returns true if flags list contains IS_SD, F_SD.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_SD, F_SD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_75rootSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rootSoftenDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_74rootSoftenDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_74rootSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rootSoftenDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.rootSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":615
 *         return "IS_SD" in self.__flags or "F_SD" in self.__flags
 * 
 *     cpdef bint rootSoftenAndNotSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The rootSoftenAndNotSoftenDuringSuffixation method returns true if flags list contains IS_SDD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_77rootSoftenAndNotSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenAndNotSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rootSoftenAndNotSoftenDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rootSoftenAndNotSoftenDuringSuff); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_77rootSoftenAndNotSoftenDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 615, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":625
 *             true if flags list contains IS_SDD.
 *         """
 *         return "IS_SDD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint verbSoftenDuringSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_SDD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 625, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":615
 *         return "IS_SD" in self.__flags or "F_SD" in self.__flags
 * 
 *     cpdef bint rootSoftenAndNotSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The rootSoftenAndNotSoftenDuringSuffixation method returns true if flags list contains IS_SDD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.rootSoftenAndNotSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_77rootSoftenAndNotSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_76rootSoftenAndNotSoftenDuringSuffixation[] = "\n        The rootSoftenAndNotSoftenDuringSuffixation method returns true if flags list contains IS_SDD.\n        IS_SDD: The bare-form final consonant can (or can not) get devoiced during vowel-initial suffixation. e.g. Kalp\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_SDD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_77rootSoftenAndNotSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rootSoftenAndNotSoftenDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_76rootSoftenAndNotSoftenDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_76rootSoftenAndNotSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rootSoftenAndNotSoftenDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenAndNotSoftenDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.rootSoftenAndNotSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":627
 *         return "IS_SDD" in self.__flags
 * 
 *     cpdef bint verbSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The verbSoftenDuringSuffixation method returns true if flags list contains F_SD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_79verbSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_verbSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("verbSoftenDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_verbSoftenDuringSuffixation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_79verbSoftenDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 627, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 627, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":637
 *             true if flags list contains F_SD.
 *         """
 *         return "F_SD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint nounSoftenDuringSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F_SD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 637, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":627
 *         return "IS_SDD" in self.__flags
 * 
 *     cpdef bint verbSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The verbSoftenDuringSuffixation method returns true if flags list contains F_SD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.verbSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_79verbSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_78verbSoftenDuringSuffixation[] = "\n        The verbSoftenDuringSuffixation method returns true if flags list contains F_SD.\n        F_SD: The bare-form final consonant gets devoiced during vowel-initial suffixation. e.g. Cezbet\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains F_SD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_79verbSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("verbSoftenDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_78verbSoftenDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_78verbSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("verbSoftenDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_verbSoftenDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.verbSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":639
 *         return "F_SD" in self.__flags
 * 
 *     cpdef bint nounSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The nounSoftenDuringSuffixation method returns true if flags list contains IS_SD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_81nounSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_nounSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nounSoftenDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nounSoftenDuringSuffixation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_81nounSoftenDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 639, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 639, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":649
 *             true if flags list contains IS_SD.
 *         """
 *         return "IS_SD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint endingKChangesIntoG(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_SD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 649, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":639
 *         return "F_SD" in self.__flags
 * 
 *     cpdef bint nounSoftenDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The nounSoftenDuringSuffixation method returns true if flags list contains IS_SD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.nounSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_81nounSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_80nounSoftenDuringSuffixation[] = "\n        The nounSoftenDuringSuffixation method returns true if flags list contains IS_SD.\n        IS_SD: The bare-form final consonant already has an accusative suffix. e.g. Kaba\304\237\304\261\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_SD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_81nounSoftenDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nounSoftenDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_80nounSoftenDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_80nounSoftenDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nounSoftenDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_nounSoftenDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.nounSoftenDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":651
 *         return "IS_SD" in self.__flags
 * 
 *     cpdef bint endingKChangesIntoG(self):             # <<<<<<<<<<<<<<
 *         """
 *         The endingKChangesIntoG method returns true if flags list contains IS_KG.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_83endingKChangesIntoG(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_endingKChangesIntoG(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("endingKChangesIntoG", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_endingKChangesIntoG); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_83endingKChangesIntoG)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":662
 *             true if flags list contains IS_KG.
 *         """
 *         return "IS_KG" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isExceptional(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_KG, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 662, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":651
 *         return "IS_SD" in self.__flags
 * 
 *     cpdef bint endingKChangesIntoG(self):             # <<<<<<<<<<<<<<
 *         """
 *         The endingKChangesIntoG method returns true if flags list contains IS_KG.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.endingKChangesIntoG", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_83endingKChangesIntoG(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_82endingKChangesIntoG[] = "\n        The endingKChangesIntoG method returns true if flags list contains IS_KG.\n        IS_KG: The bare-form includes vowel epenthesis, therefore the last inserted vowel drope\n        during suffixation. e.g. \303\207elenk\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_KG.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_83endingKChangesIntoG(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("endingKChangesIntoG (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_82endingKChangesIntoG(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_82endingKChangesIntoG(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("endingKChangesIntoG", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_endingKChangesIntoG(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.endingKChangesIntoG", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":664
 *         return "IS_KG" in self.__flags
 * 
 *     cpdef bint isExceptional(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isExceptional method returns true if flags list contains IS_EX.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_85isExceptional(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_isExceptional(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isExceptional", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isExceptional); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 664, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_85isExceptional)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 664, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":674
 *             true if flags list contains IS_EX.
 *         """
 *         return "IS_EX" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint duplicatesDuringSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_EX, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 674, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":664
 *         return "IS_KG" in self.__flags
 * 
 *     cpdef bint isExceptional(self):             # <<<<<<<<<<<<<<
 *         """
 *         The isExceptional method returns true if flags list contains IS_EX.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.isExceptional", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_85isExceptional(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_84isExceptional[] = "\n        The isExceptional method returns true if flags list contains IS_EX.\n        IS_EX: This tag defines exception words. e.g. Delikanl\304\261\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_EX.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_85isExceptional(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isExceptional (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_84isExceptional(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_84isExceptional(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isExceptional", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_isExceptional(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.isExceptional", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":676
 *         return "IS_EX" in self.__flags
 * 
 *     cpdef bint duplicatesDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The duplicatesDuringSuffixation method returns true if flags list contains IS_ST.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_87duplicatesDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicatesDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_duplicatesDuringSuffixation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 676, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_87duplicatesDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 676, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 676, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":686
 *             true if flags list contains IS_ST.
 *         """
 *         return "IS_ST" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint duplicatesAndNotDuplicatesDuringSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_ST, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 686, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":676
 *         return "IS_EX" in self.__flags
 * 
 *     cpdef bint duplicatesDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The duplicatesDuringSuffixation method returns true if flags list contains IS_ST.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.duplicatesDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_87duplicatesDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_86duplicatesDuringSuffixation[] = "\n        The duplicatesDuringSuffixation method returns true if flags list contains IS_ST.\n        IS_ST: The second consonant of the bare-form undergoes a resyllabification. e.g. His\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_ST.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_87duplicatesDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("duplicatesDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_86duplicatesDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_86duplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicatesDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.duplicatesDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":688
 *         return "IS_ST" in self.__flags
 * 
 *     cpdef bint duplicatesAndNotDuplicatesDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The duplicatesAndNotDuplicatesDuringSuffixation method returns true if flags list contains IS_STT.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_89duplicatesAndNotDuplicatesDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesAndNotDuplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicatesAndNotDuplicatesDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_duplicatesAndNotDuplicatesDuring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_89duplicatesAndNotDuplicatesDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 688, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":698
 *             true if flags list contains IS_STT.
 *         """
 *         return "IS_STT" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint lastIdropsDuringSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_STT, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 698, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":688
 *         return "IS_ST" in self.__flags
 * 
 *     cpdef bint duplicatesAndNotDuplicatesDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The duplicatesAndNotDuplicatesDuringSuffixation method returns true if flags list contains IS_STT.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.duplicatesAndNotDuplicatesDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_89duplicatesAndNotDuplicatesDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_88duplicatesAndNotDuplicatesDuringSuffixation[] = "\n        The duplicatesAndNotDuplicatesDuringSuffixation method returns true if flags list contains IS_STT.\n        IS_STT: The second consonant of the bare-form undergoes a resyllabification. e.g. His\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_STT.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_89duplicatesAndNotDuplicatesDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("duplicatesAndNotDuplicatesDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_88duplicatesAndNotDuplicatesDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_88duplicatesAndNotDuplicatesDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicatesAndNotDuplicatesDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesAndNotDuplicatesDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.duplicatesAndNotDuplicatesDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":700
 *         return "IS_STT" in self.__flags
 * 
 *     cpdef bint lastIdropsDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIdropsDuringSuffixation method returns true if flags list contains IS_UD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_91lastIdropsDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIdropsDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_lastIdropsDuringSuffixation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_91lastIdropsDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 700, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 700, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":711
 *             true if flags list contains IS_UD.
 *         """
 *         return "IS_UD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint lastIDropsAndNotDropDuringSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_UD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 711, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":700
 *         return "IS_STT" in self.__flags
 * 
 *     cpdef bint lastIdropsDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIdropsDuringSuffixation method returns true if flags list contains IS_UD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.lastIdropsDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_91lastIdropsDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_90lastIdropsDuringSuffixation[] = "\n        The lastIdropsDuringSuffixation method returns true if flags list contains IS_UD.\n        IS_UD: The bare-form includes vowel epenthesis, therefore the last inserted vowel drops during suffixation.\n        e.g. Boyun\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_UD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_91lastIdropsDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lastIdropsDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_90lastIdropsDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_90lastIdropsDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIdropsDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.lastIdropsDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":713
 *         return "IS_UD" in self.__flags
 * 
 *     cpdef bint lastIDropsAndNotDropDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIDropsAndNotDropDuringSuffixation method returns true if flags list contains IS_UDD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_93lastIDropsAndNotDropDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIDropsAndNotDropDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIDropsAndNotDropDuringSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_lastIDropsAndNotDropDuringSuffix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_93lastIDropsAndNotDropDuringSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 713, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 713, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":724
 *             true if flags list contains IS_UDD.
 *         """
 *         return "IS_UDD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint takesRelativeSuffixKi(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_UDD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 724, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":713
 *         return "IS_UD" in self.__flags
 * 
 *     cpdef bint lastIDropsAndNotDropDuringSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIDropsAndNotDropDuringSuffixation method returns true if flags list contains IS_UDD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.lastIDropsAndNotDropDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_93lastIDropsAndNotDropDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_92lastIDropsAndNotDropDuringSuffixation[] = "\n        The lastIDropsAndNotDropDuringSuffixation method returns true if flags list contains IS_UDD.\n        IS_UDD: The bare-form includes vowel epenthesis, therefore the last inserted vowel can (or can not) drop during\n        suffixation. e.g. Kadir\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_UDD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_93lastIDropsAndNotDropDuringSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lastIDropsAndNotDropDuringSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_92lastIDropsAndNotDropDuringSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_92lastIDropsAndNotDropDuringSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIDropsAndNotDropDuringSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIDropsAndNotDropDuringSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.lastIDropsAndNotDropDuringSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":726
 *         return "IS_UDD" in self.__flags
 * 
 *     cpdef bint takesRelativeSuffixKi(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesRelativeSuffixKi method returns true if flags list contains IS_KI.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_95takesRelativeSuffixKi(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKi(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesRelativeSuffixKi", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_takesRelativeSuffixKi); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_95takesRelativeSuffixKi)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 726, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 726, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":736
 *             true if flags list contains IS_KI.
 *         """
 *         return "IS_KI" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint takesRelativeSuffixKu(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_KI, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 736, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":726
 *         return "IS_UDD" in self.__flags
 * 
 *     cpdef bint takesRelativeSuffixKi(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesRelativeSuffixKi method returns true if flags list contains IS_KI.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.takesRelativeSuffixKi", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_95takesRelativeSuffixKi(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_94takesRelativeSuffixKi[] = "\n        The takesRelativeSuffixKi method returns true if flags list contains IS_KI.\n        IS_KI: The word can take a suffix such as \"ki\". e.g. \303\226nce\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_KI.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_95takesRelativeSuffixKi(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("takesRelativeSuffixKi (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_94takesRelativeSuffixKi(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_94takesRelativeSuffixKi(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesRelativeSuffixKi", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKi(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.takesRelativeSuffixKi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":738
 *         return "IS_KI" in self.__flags
 * 
 *     cpdef bint takesRelativeSuffixKu(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesRelativeSuffixKu method returns true if flags list contains IS_KU.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_97takesRelativeSuffixKu(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKu(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesRelativeSuffixKu", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_takesRelativeSuffixKu); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_97takesRelativeSuffixKu)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 738, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":748
 *             true if flags list contains IS_KU.
 *         """
 *         return "IS_KU" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint consonantSMayInsertedDuringPossesiveSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_KU, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 748, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":738
 *         return "IS_KI" in self.__flags
 * 
 *     cpdef bint takesRelativeSuffixKu(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesRelativeSuffixKu method returns true if flags list contains IS_KU.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.takesRelativeSuffixKu", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_97takesRelativeSuffixKu(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_96takesRelativeSuffixKu[] = "\n        The takesRelativeSuffixKu method returns true if flags list contains IS_KU.\n        IS_KU: The word can take a suffix such as \"k\303\274\". e.g. Bug\303\274n\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_KU.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_97takesRelativeSuffixKu(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("takesRelativeSuffixKu (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_96takesRelativeSuffixKu(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_96takesRelativeSuffixKu(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesRelativeSuffixKu", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKu(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.takesRelativeSuffixKu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":750
 *         return "IS_KU" in self.__flags
 * 
 *     cpdef bint consonantSMayInsertedDuringPossesiveSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The consonantSMayInsertedDuringPossesiveSuffixation method returns true if flags list contains IS_SII.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_99consonantSMayInsertedDuringPossesiveSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_consonantSMayInsertedDuringPossesiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("consonantSMayInsertedDuringPossesiveSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_consonantSMayInsertedDuringPosse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_99consonantSMayInsertedDuringPossesiveSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 750, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":759
 *             true if flags list contains IS_SII.
 *         """
 *         return "IS_SII" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint lastIdropsDuringPassiveSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_SII, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 759, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":750
 *         return "IS_KU" in self.__flags
 * 
 *     cpdef bint consonantSMayInsertedDuringPossesiveSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The consonantSMayInsertedDuringPossesiveSuffixation method returns true if flags list contains IS_SII.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.consonantSMayInsertedDuringPossesiveSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_99consonantSMayInsertedDuringPossesiveSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_98consonantSMayInsertedDuringPossesiveSuffixation[] = "\n        The consonantSMayInsertedDuringPossesiveSuffixation method returns true if flags list contains IS_SII.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_SII.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_99consonantSMayInsertedDuringPossesiveSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("consonantSMayInsertedDuringPossesiveSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_98consonantSMayInsertedDuringPossesiveSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_98consonantSMayInsertedDuringPossesiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("consonantSMayInsertedDuringPossesiveSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_consonantSMayInsertedDuringPossesiveSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.consonantSMayInsertedDuringPossesiveSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":761
 *         return "IS_SII" in self.__flags
 * 
 *     cpdef bint lastIdropsDuringPassiveSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIdropsDuringPassiveSuffixation method returns true if flags list contains F_UD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_101lastIdropsDuringPassiveSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringPassiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIdropsDuringPassiveSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_lastIdropsDuringPassiveSuffixati); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_101lastIdropsDuringPassiveSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 761, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":772
 *             true if flags list contains F_UD.
 *         """
 *         return "F_UD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint vowelAChangesToIDuringYSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F_UD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 772, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":761
 *         return "IS_SII" in self.__flags
 * 
 *     cpdef bint lastIdropsDuringPassiveSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The lastIdropsDuringPassiveSuffixation method returns true if flags list contains F_UD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.lastIdropsDuringPassiveSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_101lastIdropsDuringPassiveSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_100lastIdropsDuringPassiveSuffixation[] = "\n        The lastIdropsDuringPassiveSuffixation method returns true if flags list contains F_UD.\n        F_UD: The bare-form includes vowel epenthesis, therefore the last \"\304\261\"\n        drops during passive suffixation. e.g. \303\207a\304\237\304\261r\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains F_UD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_101lastIdropsDuringPassiveSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lastIdropsDuringPassiveSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_100lastIdropsDuringPassiveSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_100lastIdropsDuringPassiveSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lastIdropsDuringPassiveSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringPassiveSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.lastIdropsDuringPassiveSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":774
 *         return "F_UD" in self.__flags
 * 
 *     cpdef bint vowelAChangesToIDuringYSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The vowelAChangesToIDuringYSuffixation method returns true if flags list contains F_GUD.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_103vowelAChangesToIDuringYSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelAChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vowelAChangesToIDuringYSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_vowelAChangesToIDuringYSuffixati); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 774, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_103vowelAChangesToIDuringYSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 774, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 774, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":785
 *             true if flags list contains F_GUD.
 *         """
 *         return "F_GUD" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint vowelEChangesToIDuringYSuffixation(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F_GUD, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 785, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":774
 *         return "F_UD" in self.__flags
 * 
 *     cpdef bint vowelAChangesToIDuringYSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The vowelAChangesToIDuringYSuffixation method returns true if flags list contains F_GUD.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.vowelAChangesToIDuringYSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_103vowelAChangesToIDuringYSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_102vowelAChangesToIDuringYSuffixation[] = "\n        The vowelAChangesToIDuringYSuffixation method returns true if flags list contains F_GUD.\n        F_GUD: The verb bare-form includes vowel reduction, the last vowel \"a\" of the bare-form is replaced with \"\304\261\"\n        e.g. Buza\304\237\304\261la\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains F_GUD.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_103vowelAChangesToIDuringYSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vowelAChangesToIDuringYSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_102vowelAChangesToIDuringYSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_102vowelAChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vowelAChangesToIDuringYSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelAChangesToIDuringYSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.vowelAChangesToIDuringYSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":787
 *         return "F_GUD" in self.__flags
 * 
 *     cpdef bint vowelEChangesToIDuringYSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The vowelEChangesToIDuringYSuffixation method returns true if flags list contains F_GUDO.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_105vowelEChangesToIDuringYSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelEChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vowelEChangesToIDuringYSuffixation", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_vowelEChangesToIDuringYSuffixati); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 787, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_105vowelEChangesToIDuringYSuffixation)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 787, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 787, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":798
 *             true if flags list contains F_GUDO.
 *         """
 *         return "F_GUDO" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint takesSuffixIRAsAorist(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F_GUDO, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 798, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":787
 *         return "F_GUD" in self.__flags
 * 
 *     cpdef bint vowelEChangesToIDuringYSuffixation(self):             # <<<<<<<<<<<<<<
 *         """
 *         The vowelEChangesToIDuringYSuffixation method returns true if flags list contains F_GUDO.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.vowelEChangesToIDuringYSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_105vowelEChangesToIDuringYSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_104vowelEChangesToIDuringYSuffixation[] = "\n        The vowelEChangesToIDuringYSuffixation method returns true if flags list contains F_GUDO.\n        F_GUDO: The verb bare-form includes viwel reduction, the last vowel \"e\" of the\n        bare-form is replaced with \"i\". e.g. Ye\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains F_GUDO.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_105vowelEChangesToIDuringYSuffixation(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vowelEChangesToIDuringYSuffixation (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_104vowelEChangesToIDuringYSuffixation(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_104vowelEChangesToIDuringYSuffixation(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vowelEChangesToIDuringYSuffixation", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelEChangesToIDuringYSuffixation(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.vowelEChangesToIDuringYSuffixation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":800
 *         return "F_GUDO" in self.__flags
 * 
 *     cpdef bint takesSuffixIRAsAorist(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesSuffixIRAsAorist method returns true if flags list contains F_GIR.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_107takesSuffixIRAsAorist(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixIRAsAorist(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesSuffixIRAsAorist", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_takesSuffixIRAsAorist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 800, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_107takesSuffixIRAsAorist)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 800, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":810
 *             true if flags list contains F_GIR.
 *         """
 *         return "F_GIR" not in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint takesSuffixDIRAsFactitive(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F_GIR, __pyx_v_self->__pyx___flags, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 810, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":800
 *         return "F_GUDO" in self.__flags
 * 
 *     cpdef bint takesSuffixIRAsAorist(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesSuffixIRAsAorist method returns true if flags list contains F_GIR.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.takesSuffixIRAsAorist", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_107takesSuffixIRAsAorist(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_106takesSuffixIRAsAorist[] = "\n        The takesSuffixIRAsAorist method returns true if flags list contains F_GIR.\n        F_GIR: The bare-form of the word takes \"ir\" suffix. e.g. Ge\303\247\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains F_GIR.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_107takesSuffixIRAsAorist(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("takesSuffixIRAsAorist (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_106takesSuffixIRAsAorist(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_106takesSuffixIRAsAorist(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesSuffixIRAsAorist", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixIRAsAorist(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.takesSuffixIRAsAorist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":812
 *         return "F_GIR" not in self.__flags
 * 
 *     cpdef bint takesSuffixDIRAsFactitive(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesSuffixDIRAsFactitive method returns true if flags list contains F_DIR.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_109takesSuffixDIRAsFactitive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixDIRAsFactitive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesSuffixDIRAsFactitive", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_takesSuffixDIRAsFactitive); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 812, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_109takesSuffixDIRAsFactitive)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 812, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 812, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":822
 *             true if flags list contains F_DIR.
 *         """
 *         return "F_DIR" not in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint showsSuRegularities(self):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_F_DIR, __pyx_v_self->__pyx___flags, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 822, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":812
 *         return "F_GIR" not in self.__flags
 * 
 *     cpdef bint takesSuffixDIRAsFactitive(self):             # <<<<<<<<<<<<<<
 *         """
 *         The takesSuffixDIRAsFactitive method returns true if flags list contains F_DIR.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.takesSuffixDIRAsFactitive", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_109takesSuffixDIRAsFactitive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_108takesSuffixDIRAsFactitive[] = "\n        The takesSuffixDIRAsFactitive method returns true if flags list contains F_DIR.\n        F_DIR: The bare-form of the word takes \"t\304\261r\" suffix. e.g. Daral\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains F_DIR.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_109takesSuffixDIRAsFactitive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("takesSuffixDIRAsFactitive (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_108takesSuffixDIRAsFactitive(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_108takesSuffixDIRAsFactitive(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("takesSuffixDIRAsFactitive", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixDIRAsFactitive(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.takesSuffixDIRAsFactitive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":824
 *         return "F_DIR" not in self.__flags
 * 
 *     cpdef bint showsSuRegularities(self):             # <<<<<<<<<<<<<<
 *         """
 *         The showsSuRegularities method returns true if flags list contains IS_SU.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_111showsSuRegularities(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_showsSuRegularities(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("showsSuRegularities", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_showsSuRegularities); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_111showsSuRegularities)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":833
 *             true if flags list contains IS_SU.
 *         """
 *         return "IS_SU" in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint containsFlag(self, str flag):
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_IS_SU, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 833, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":824
 *         return "F_DIR" not in self.__flags
 * 
 *     cpdef bint showsSuRegularities(self):             # <<<<<<<<<<<<<<
 *         """
 *         The showsSuRegularities method returns true if flags list contains IS_SU.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.showsSuRegularities", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_111showsSuRegularities(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_110showsSuRegularities[] = "\n        The showsSuRegularities method returns true if flags list contains IS_SU.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains IS_SU.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_111showsSuRegularities(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("showsSuRegularities (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_110showsSuRegularities(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_110showsSuRegularities(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("showsSuRegularities", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_showsSuRegularities(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.showsSuRegularities", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":835
 *         return "IS_SU" in self.__flags
 * 
 *     cpdef bint containsFlag(self, str flag):             # <<<<<<<<<<<<<<
 *         """
 *         The containsFlag method returns true if flags list contains flag.
 */

static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_113containsFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /*proto*/
static int __pyx_f_10Dictionary_7TxtWord_7TxtWord_containsFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("containsFlag", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_containsFlag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 835, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_113containsFlag)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_flag) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_flag);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 835, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 835, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "Dictionary/TxtWord.pyx":844
 *             true if flags list contains flag.
 *         """
 *         return flag in self.__flags             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self) -> str:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_v_flag, __pyx_v_self->__pyx___flags, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 844, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":835
 *         return "IS_SU" in self.__flags
 * 
 *     cpdef bint containsFlag(self, str flag):             # <<<<<<<<<<<<<<
 *         """
 *         The containsFlag method returns true if flags list contains flag.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("Dictionary.TxtWord.TxtWord.containsFlag", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_113containsFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /*proto*/
static char __pyx_doc_10Dictionary_7TxtWord_7TxtWord_112containsFlag[] = "\n        The containsFlag method returns true if flags list contains flag.\n\n        RETURNS\n        -------\n        bool\n            true if flags list contains flag.\n        ";
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_113containsFlag(PyObject *__pyx_v_self, PyObject *__pyx_v_flag) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("containsFlag (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_flag), (&PyUnicode_Type), 1, "flag", 1))) __PYX_ERR(0, 835, __pyx_L1_error)
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_112containsFlag(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self), ((PyObject*)__pyx_v_flag));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_112containsFlag(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v_flag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("containsFlag", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_10Dictionary_7TxtWord_7TxtWord_containsFlag(__pyx_v_self, __pyx_v_flag, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.containsFlag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "Dictionary/TxtWord.pyx":846
 *         return flag in self.__flags
 * 
 *     def __str__(self) -> str:             # <<<<<<<<<<<<<<
 *         result = super().__str__()
 *         for flag in self.__flags:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_115__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_115__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_114__str__(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_114__str__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_flag = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "Dictionary/TxtWord.pyx":847
 * 
 *     def __str__(self) -> str:
 *         result = super().__str__()             # <<<<<<<<<<<<<<
 *         for flag in self.__flags:
 *             result = result + " " + flag
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord));
  __Pyx_GIVEREF(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord));
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self));
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "Dictionary/TxtWord.pyx":848
 *     def __str__(self) -> str:
 *         result = super().__str__()
 *         for flag in self.__flags:             # <<<<<<<<<<<<<<
 *             result = result + " " + flag
 *         return result
 */
  if (unlikely(__pyx_v_self->__pyx___flags == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 848, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->__pyx___flags; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
  for (;;) {
    if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 848, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 848, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_flag, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "Dictionary/TxtWord.pyx":849
 *         result = super().__str__()
 *         for flag in self.__flags:
 *             result = result + " " + flag             # <<<<<<<<<<<<<<
 *         return result
 */
    __pyx_t_2 = PyNumber_Add(__pyx_v_result, __pyx_kp_u__2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_flag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "Dictionary/TxtWord.pyx":848
 *     def __str__(self) -> str:
 *         result = super().__str__()
 *         for flag in self.__flags:             # <<<<<<<<<<<<<<
 *             result = result + " " + flag
 *         return result
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Dictionary/TxtWord.pyx":850
 *         for flag in self.__flags:
 *             result = result + " " + flag
 *         return result             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "Dictionary/TxtWord.pyx":846
 *         return flag in self.__flags
 * 
 *     def __str__(self) -> str:             # <<<<<<<<<<<<<<
 *         result = super().__str__()
 *         for flag in self.__flags:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_flag);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_117__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_117__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_116__reduce_cython__(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_116__reduce_cython__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.__flags, self.name)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->__pyx___flags);
  __Pyx_GIVEREF(__pyx_v_self->__pyx___flags);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx___flags);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.name);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.name);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->__pyx_base.name);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.__flags, self.name)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.__flags, self.name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.__flags is not None or self.name is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.__flags, self.name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.__flags is not None or self.name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->__pyx___flags != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx_base.name != ((PyObject*)Py_None));
    __pyx_t_2 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__flags is not None or self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.__flags is not None or self.name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_TxtWord); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_243029568);
    __Pyx_GIVEREF(__pyx_int_243029568);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_243029568);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__flags is not None or self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, None), state
 *     else:
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_TxtWord__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_TxtWord); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_243029568);
    __Pyx_GIVEREF(__pyx_int_243029568);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_243029568);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_TxtWord__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_119__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_10Dictionary_7TxtWord_7TxtWord_119__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord_7TxtWord_118__setstate_cython__(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord_7TxtWord_118__setstate_cython__(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_TxtWord__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_10Dictionary_7TxtWord___pyx_unpickle_TxtWord__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_TxtWord, (type(self), 0xe7c5640, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_TxtWord__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("Dictionary.TxtWord.TxtWord.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_TxtWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_10Dictionary_7TxtWord_1__pyx_unpickle_TxtWord(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10Dictionary_7TxtWord_1__pyx_unpickle_TxtWord = {"__pyx_unpickle_TxtWord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_10Dictionary_7TxtWord_1__pyx_unpickle_TxtWord, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10Dictionary_7TxtWord_1__pyx_unpickle_TxtWord(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_TxtWord (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_TxtWord", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_TxtWord", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_TxtWord") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_TxtWord", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("Dictionary.TxtWord.__pyx_unpickle_TxtWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10Dictionary_7TxtWord___pyx_unpickle_TxtWord(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10Dictionary_7TxtWord___pyx_unpickle_TxtWord(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_TxtWord", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xe7c5640:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xe7c5640) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xe7c5640:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))" % __pyx_checksum)
 *     __pyx_result = TxtWord.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xe7c5640:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = TxtWord.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xe7, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xe7c5640:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))" % __pyx_checksum)
 *     __pyx_result = TxtWord.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_TxtWord__set_state(<TxtWord> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_10Dictionary_7TxtWord_TxtWord), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))" % __pyx_checksum)
 *     __pyx_result = TxtWord.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_TxtWord__set_state(<TxtWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = TxtWord.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_TxtWord__set_state(<TxtWord> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_TxtWord__set_state(TxtWord __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_10Dictionary_7TxtWord___pyx_unpickle_TxtWord__set_state(((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xe7c5640 = (__flags, name))" % __pyx_checksum)
 *     __pyx_result = TxtWord.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_TxtWord__set_state(<TxtWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_TxtWord__set_state(<TxtWord> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_TxtWord__set_state(TxtWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__flags = __pyx_state[0]; __pyx_result.name = __pyx_state[1]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_TxtWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("Dictionary.TxtWord.__pyx_unpickle_TxtWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_TxtWord__set_state(<TxtWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_TxtWord__set_state(TxtWord __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__flags = __pyx_state[0]; __pyx_result.name = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_10Dictionary_7TxtWord___pyx_unpickle_TxtWord__set_state(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_TxtWord__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_TxtWord__set_state(TxtWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__flags = __pyx_state[0]; __pyx_result.name = __pyx_state[1]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx___flags);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx___flags);
  __pyx_v___pyx_result->__pyx___flags = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.name);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.name);
  __pyx_v___pyx_result->__pyx_base.name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_TxtWord__set_state(TxtWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__flags = __pyx_state[0]; __pyx_result.name = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 2) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.__flags = __pyx_state[0]; __pyx_result.name = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_TxtWord__set_state(TxtWord __pyx_result, tuple __pyx_state):
 *     __pyx_result.__flags = __pyx_state[0]; __pyx_result.name = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_TxtWord__set_state(<TxtWord> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_TxtWord__set_state(TxtWord __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__flags = __pyx_state[0]; __pyx_result.name = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("Dictionary.TxtWord.__pyx_unpickle_TxtWord__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_10Dictionary_7TxtWord_TxtWord __pyx_vtable_10Dictionary_7TxtWord_TxtWord;

static PyObject *__pyx_tp_new_10Dictionary_7TxtWord_TxtWord(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *p;
  PyObject *o = __pyx_ptype_10Dictionary_4Word_Word->tp_new(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__pyx_vtabptr_10Dictionary_7TxtWord_TxtWord;
  p->__pyx___flags = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_10Dictionary_7TxtWord_TxtWord(PyObject *o) {
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *p = (struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx___flags);
  #if CYTHON_USE_TYPE_SLOTS
  if (PyType_IS_GC(Py_TYPE(o)->tp_base))
  #endif
  PyObject_GC_Track(o);
  if (likely(__pyx_ptype_10Dictionary_4Word_Word)) __pyx_ptype_10Dictionary_4Word_Word->tp_dealloc(o); else __Pyx_call_next_tp_dealloc(o, __pyx_tp_dealloc_10Dictionary_7TxtWord_TxtWord);
}

static int __pyx_tp_traverse_10Dictionary_7TxtWord_TxtWord(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *p = (struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)o;
  e = ((likely(__pyx_ptype_10Dictionary_4Word_Word)) ? ((__pyx_ptype_10Dictionary_4Word_Word->tp_traverse) ? __pyx_ptype_10Dictionary_4Word_Word->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_10Dictionary_7TxtWord_TxtWord)); if (e) return e;
  if (p->__pyx___flags) {
    e = (*v)(p->__pyx___flags, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10Dictionary_7TxtWord_TxtWord(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *p = (struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *)o;
  if (likely(__pyx_ptype_10Dictionary_4Word_Word)) { if (__pyx_ptype_10Dictionary_4Word_Word->tp_clear) __pyx_ptype_10Dictionary_4Word_Word->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_10Dictionary_7TxtWord_TxtWord);
  tmp = ((PyObject*)p->__pyx___flags);
  p->__pyx___flags = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_10Dictionary_7TxtWord_TxtWord[] = {
  {"addFlag", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_3addFlag, METH_O, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_2addFlag},
  {"removeFlag", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_5removeFlag, METH_O, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_4removeFlag},
  {"verbType", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_7verbType, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_6verbType},
  {"samePos", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_9samePos, METH_O, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_8samePos},
  {"isNominal", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_11isNominal, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_10isNominal},
  {"isPassive", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_13isPassive, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_12isPassive},
  {"isAbbreviation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_15isAbbreviation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_14isAbbreviation},
  {"isInterjection", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_17isInterjection, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_16isInterjection},
  {"isDuplicate", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_19isDuplicate, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_18isDuplicate},
  {"isHeader", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_21isHeader, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_20isHeader},
  {"isAdjective", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_23isAdjective, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_22isAdjective},
  {"isPureAdjective", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_25isPureAdjective, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_24isPureAdjective},
  {"isPronoun", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_27isPronoun, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_26isPronoun},
  {"isQuestion", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_29isQuestion, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_28isQuestion},
  {"isVerb", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_31isVerb, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_30isVerb},
  {"isPortmanteau", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_33isPortmanteau, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_32isPortmanteau},
  {"isDeterminer", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_35isDeterminer, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_34isDeterminer},
  {"isConjunction", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_37isConjunction, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_36isConjunction},
  {"isAdverb", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_39isAdverb, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_38isAdverb},
  {"isPostP", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_41isPostP, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_40isPostP},
  {"isPortmanteauEndingWithSI", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_43isPortmanteauEndingWithSI, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_42isPortmanteauEndingWithSI},
  {"isPortmanteauFacedVowelEllipsis", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_45isPortmanteauFacedVowelEllipsis, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_44isPortmanteauFacedVowelEllipsis},
  {"isPortmanteauFacedSoftening", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_47isPortmanteauFacedSoftening, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_46isPortmanteauFacedSoftening},
  {"isSuffix", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_49isSuffix, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_48isSuffix},
  {"isProperNoun", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_51isProperNoun, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_50isProperNoun},
  {"isPlural", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_53isPlural, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_52isPlural},
  {"isNumeral", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_55isNumeral, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_54isNumeral},
  {"isReal", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_57isReal, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_56isReal},
  {"isFraction", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_59isFraction, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_58isFraction},
  {"isTime", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_61isTime, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_60isTime},
  {"isDate", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_63isDate, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_62isDate},
  {"isPercent", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_65isPercent, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_64isPercent},
  {"isRange", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_67isRange, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_66isRange},
  {"isOrdinal", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_69isOrdinal, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_68isOrdinal},
  {"notObeysVowelHarmonyDuringAgglutination", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_71notObeysVowelHarmonyDuringAgglutination, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_70notObeysVowelHarmonyDuringAgglutination},
  {"obeysAndNotObeysVowelHarmonyDuringAgglutination", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_73obeysAndNotObeysVowelHarmonyDuringAgglutination, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_72obeysAndNotObeysVowelHarmonyDuringAgglutination},
  {"rootSoftenDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_75rootSoftenDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_74rootSoftenDuringSuffixation},
  {"rootSoftenAndNotSoftenDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_77rootSoftenAndNotSoftenDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_76rootSoftenAndNotSoftenDuringSuffixation},
  {"verbSoftenDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_79verbSoftenDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_78verbSoftenDuringSuffixation},
  {"nounSoftenDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_81nounSoftenDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_80nounSoftenDuringSuffixation},
  {"endingKChangesIntoG", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_83endingKChangesIntoG, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_82endingKChangesIntoG},
  {"isExceptional", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_85isExceptional, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_84isExceptional},
  {"duplicatesDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_87duplicatesDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_86duplicatesDuringSuffixation},
  {"duplicatesAndNotDuplicatesDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_89duplicatesAndNotDuplicatesDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_88duplicatesAndNotDuplicatesDuringSuffixation},
  {"lastIdropsDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_91lastIdropsDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_90lastIdropsDuringSuffixation},
  {"lastIDropsAndNotDropDuringSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_93lastIDropsAndNotDropDuringSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_92lastIDropsAndNotDropDuringSuffixation},
  {"takesRelativeSuffixKi", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_95takesRelativeSuffixKi, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_94takesRelativeSuffixKi},
  {"takesRelativeSuffixKu", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_97takesRelativeSuffixKu, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_96takesRelativeSuffixKu},
  {"consonantSMayInsertedDuringPossesiveSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_99consonantSMayInsertedDuringPossesiveSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_98consonantSMayInsertedDuringPossesiveSuffixation},
  {"lastIdropsDuringPassiveSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_101lastIdropsDuringPassiveSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_100lastIdropsDuringPassiveSuffixation},
  {"vowelAChangesToIDuringYSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_103vowelAChangesToIDuringYSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_102vowelAChangesToIDuringYSuffixation},
  {"vowelEChangesToIDuringYSuffixation", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_105vowelEChangesToIDuringYSuffixation, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_104vowelEChangesToIDuringYSuffixation},
  {"takesSuffixIRAsAorist", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_107takesSuffixIRAsAorist, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_106takesSuffixIRAsAorist},
  {"takesSuffixDIRAsFactitive", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_109takesSuffixDIRAsFactitive, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_108takesSuffixDIRAsFactitive},
  {"showsSuRegularities", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_111showsSuRegularities, METH_NOARGS, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_110showsSuRegularities},
  {"containsFlag", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_113containsFlag, METH_O, __pyx_doc_10Dictionary_7TxtWord_7TxtWord_112containsFlag},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_117__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_10Dictionary_7TxtWord_7TxtWord_119__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_10Dictionary_7TxtWord_TxtWord = {
  PyVarObject_HEAD_INIT(0, 0)
  "Dictionary.TxtWord.TxtWord", /*tp_name*/
  sizeof(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10Dictionary_7TxtWord_TxtWord, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_10Dictionary_7TxtWord_7TxtWord_115__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10Dictionary_7TxtWord_TxtWord, /*tp_traverse*/
  __pyx_tp_clear_10Dictionary_7TxtWord_TxtWord, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_10Dictionary_7TxtWord_TxtWord, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_10Dictionary_7TxtWord_7TxtWord_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10Dictionary_7TxtWord_TxtWord, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_TxtWord(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_TxtWord},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "TxtWord",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
  {&__pyx_n_u_CL_FIIL, __pyx_k_CL_FIIL, sizeof(__pyx_k_CL_FIIL), 0, 1, 0, 1},
  {&__pyx_n_u_CL_ISIM, __pyx_k_CL_ISIM, sizeof(__pyx_k_CL_ISIM), 0, 1, 0, 1},
  {&__pyx_n_s_Dictionary_TxtWord, __pyx_k_Dictionary_TxtWord, sizeof(__pyx_k_Dictionary_TxtWord), 0, 0, 1, 1},
  {&__pyx_n_u_EK, __pyx_k_EK, sizeof(__pyx_k_EK), 0, 1, 0, 1},
  {&__pyx_n_u_F1P1, __pyx_k_F1P1, sizeof(__pyx_k_F1P1), 0, 1, 0, 1},
  {&__pyx_kp_u_F1P1_NO_REF, __pyx_k_F1P1_NO_REF, sizeof(__pyx_k_F1P1_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F2P1, __pyx_k_F2P1, sizeof(__pyx_k_F2P1), 0, 1, 0, 1},
  {&__pyx_kp_u_F2P1_NO_REF, __pyx_k_F2P1_NO_REF, sizeof(__pyx_k_F2P1_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F2PL, __pyx_k_F2PL, sizeof(__pyx_k_F2PL), 0, 1, 0, 1},
  {&__pyx_n_u_F3P1, __pyx_k_F3P1, sizeof(__pyx_k_F3P1), 0, 1, 0, 1},
  {&__pyx_kp_u_F3P1_NO_REF, __pyx_k_F3P1_NO_REF, sizeof(__pyx_k_F3P1_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F4P1, __pyx_k_F4P1, sizeof(__pyx_k_F4P1), 0, 1, 0, 1},
  {&__pyx_kp_u_F4P1_NO_REF, __pyx_k_F4P1_NO_REF, sizeof(__pyx_k_F4P1_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F4PL, __pyx_k_F4PL, sizeof(__pyx_k_F4PL), 0, 1, 0, 1},
  {&__pyx_kp_u_F4PL_NO_REF, __pyx_k_F4PL_NO_REF, sizeof(__pyx_k_F4PL_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F4PR, __pyx_k_F4PR, sizeof(__pyx_k_F4PR), 0, 1, 0, 1},
  {&__pyx_kp_u_F4PR_NO_REF, __pyx_k_F4PR_NO_REF, sizeof(__pyx_k_F4PR_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F4PW, __pyx_k_F4PW, sizeof(__pyx_k_F4PW), 0, 1, 0, 1},
  {&__pyx_kp_u_F4PW_NO_REF, __pyx_k_F4PW_NO_REF, sizeof(__pyx_k_F4PW_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F5P1, __pyx_k_F5P1, sizeof(__pyx_k_F5P1), 0, 1, 0, 1},
  {&__pyx_n_u_F5PL, __pyx_k_F5PL, sizeof(__pyx_k_F5PL), 0, 1, 0, 1},
  {&__pyx_kp_u_F5PL_NO_REF, __pyx_k_F5PL_NO_REF, sizeof(__pyx_k_F5PL_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F5PR, __pyx_k_F5PR, sizeof(__pyx_k_F5PR), 0, 1, 0, 1},
  {&__pyx_kp_u_F5PR_NO_REF, __pyx_k_F5PR_NO_REF, sizeof(__pyx_k_F5PR_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F5PW, __pyx_k_F5PW, sizeof(__pyx_k_F5PW), 0, 1, 0, 1},
  {&__pyx_kp_u_F5PW_NO_REF, __pyx_k_F5PW_NO_REF, sizeof(__pyx_k_F5PW_NO_REF), 0, 1, 0, 0},
  {&__pyx_n_u_F6P1, __pyx_k_F6P1, sizeof(__pyx_k_F6P1), 0, 1, 0, 1},
  {&__pyx_n_u_F_DIR, __pyx_k_F_DIR, sizeof(__pyx_k_F_DIR), 0, 1, 0, 1},
  {&__pyx_n_u_F_GIR, __pyx_k_F_GIR, sizeof(__pyx_k_F_GIR), 0, 1, 0, 1},
  {&__pyx_n_u_F_GUD, __pyx_k_F_GUD, sizeof(__pyx_k_F_GUD), 0, 1, 0, 1},
  {&__pyx_n_u_F_GUDO, __pyx_k_F_GUDO, sizeof(__pyx_k_F_GUDO), 0, 1, 0, 1},
  {&__pyx_n_u_F_SD, __pyx_k_F_SD, sizeof(__pyx_k_F_SD), 0, 1, 0, 1},
  {&__pyx_n_u_F_UD, __pyx_k_F_UD, sizeof(__pyx_k_F_UD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ADJ, __pyx_k_IS_ADJ, sizeof(__pyx_k_IS_ADJ), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ADVERB, __pyx_k_IS_ADVERB, sizeof(__pyx_k_IS_ADVERB), 0, 1, 0, 1},
  {&__pyx_n_u_IS_BILE, __pyx_k_IS_BILE, sizeof(__pyx_k_IS_BILE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_B_SD, __pyx_k_IS_B_SD, sizeof(__pyx_k_IS_B_SD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_B_SI, __pyx_k_IS_B_SI, sizeof(__pyx_k_IS_B_SI), 0, 1, 0, 1},
  {&__pyx_n_u_IS_B_UD, __pyx_k_IS_B_UD, sizeof(__pyx_k_IS_B_UD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_CA, __pyx_k_IS_CA, sizeof(__pyx_k_IS_CA), 0, 1, 0, 1},
  {&__pyx_n_u_IS_CONJ, __pyx_k_IS_CONJ, sizeof(__pyx_k_IS_CONJ), 0, 1, 0, 1},
  {&__pyx_n_u_IS_DATE, __pyx_k_IS_DATE, sizeof(__pyx_k_IS_DATE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_DET, __pyx_k_IS_DET, sizeof(__pyx_k_IS_DET), 0, 1, 0, 1},
  {&__pyx_n_u_IS_DUP, __pyx_k_IS_DUP, sizeof(__pyx_k_IS_DUP), 0, 1, 0, 1},
  {&__pyx_n_u_IS_EX, __pyx_k_IS_EX, sizeof(__pyx_k_IS_EX), 0, 1, 0, 1},
  {&__pyx_n_u_IS_HEADER, __pyx_k_IS_HEADER, sizeof(__pyx_k_IS_HEADER), 0, 1, 0, 1},
  {&__pyx_n_u_IS_INTERJ, __pyx_k_IS_INTERJ, sizeof(__pyx_k_IS_INTERJ), 0, 1, 0, 1},
  {&__pyx_n_u_IS_KESIR, __pyx_k_IS_KESIR, sizeof(__pyx_k_IS_KESIR), 0, 1, 0, 1},
  {&__pyx_n_u_IS_KG, __pyx_k_IS_KG, sizeof(__pyx_k_IS_KG), 0, 1, 0, 1},
  {&__pyx_n_u_IS_KI, __pyx_k_IS_KI, sizeof(__pyx_k_IS_KI), 0, 1, 0, 1},
  {&__pyx_n_u_IS_KIS, __pyx_k_IS_KIS, sizeof(__pyx_k_IS_KIS), 0, 1, 0, 1},
  {&__pyx_n_u_IS_KU, __pyx_k_IS_KU, sizeof(__pyx_k_IS_KU), 0, 1, 0, 1},
  {&__pyx_n_u_IS_OA, __pyx_k_IS_OA, sizeof(__pyx_k_IS_OA), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ORD, __pyx_k_IS_ORD, sizeof(__pyx_k_IS_ORD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_PERCENT, __pyx_k_IS_PERCENT, sizeof(__pyx_k_IS_PERCENT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_POSTP, __pyx_k_IS_POSTP, sizeof(__pyx_k_IS_POSTP), 0, 1, 0, 1},
  {&__pyx_n_u_IS_PUREADJ, __pyx_k_IS_PUREADJ, sizeof(__pyx_k_IS_PUREADJ), 0, 1, 0, 1},
  {&__pyx_n_u_IS_QUES, __pyx_k_IS_QUES, sizeof(__pyx_k_IS_QUES), 0, 1, 0, 1},
  {&__pyx_n_u_IS_RANGE, __pyx_k_IS_RANGE, sizeof(__pyx_k_IS_RANGE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_REELSAYI, __pyx_k_IS_REELSAYI, sizeof(__pyx_k_IS_REELSAYI), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SAYI, __pyx_k_IS_SAYI, sizeof(__pyx_k_IS_SAYI), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SD, __pyx_k_IS_SD, sizeof(__pyx_k_IS_SD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SDD, __pyx_k_IS_SDD, sizeof(__pyx_k_IS_SDD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SII, __pyx_k_IS_SII, sizeof(__pyx_k_IS_SII), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ST, __pyx_k_IS_ST, sizeof(__pyx_k_IS_ST), 0, 1, 0, 1},
  {&__pyx_n_u_IS_STT, __pyx_k_IS_STT, sizeof(__pyx_k_IS_STT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SU, __pyx_k_IS_SU, sizeof(__pyx_k_IS_SU), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UD, __pyx_k_IS_UD, sizeof(__pyx_k_IS_UD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UDD, __pyx_k_IS_UDD, sizeof(__pyx_k_IS_UDD), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UU, __pyx_k_IS_UU, sizeof(__pyx_k_IS_UU), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UUU, __pyx_k_IS_UUU, sizeof(__pyx_k_IS_UUU), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ZAMAN, __pyx_k_IS_ZAMAN, sizeof(__pyx_k_IS_ZAMAN), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ZM, __pyx_k_IS_ZM, sizeof(__pyx_k_IS_ZM), 0, 1, 0, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xe7, __pyx_k_Incompatible_checksums_s_vs_0xe7, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xe7), 0, 0, 1, 0},
  {&__pyx_kp_u_PASSIVE_HN, __pyx_k_PASSIVE_HN, sizeof(__pyx_k_PASSIVE_HN), 0, 1, 0, 0},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_TxtWord, __pyx_k_TxtWord, sizeof(__pyx_k_TxtWord), 0, 0, 1, 1},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_n_s_addFlag, __pyx_k_addFlag, sizeof(__pyx_k_addFlag), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_consonantSMayInsertedDuringPosse, __pyx_k_consonantSMayInsertedDuringPosse, sizeof(__pyx_k_consonantSMayInsertedDuringPosse), 0, 0, 1, 1},
  {&__pyx_n_s_containsFlag, __pyx_k_containsFlag, sizeof(__pyx_k_containsFlag), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_duplicatesAndNotDuplicatesDuring, __pyx_k_duplicatesAndNotDuplicatesDuring, sizeof(__pyx_k_duplicatesAndNotDuplicatesDuring), 0, 0, 1, 1},
  {&__pyx_n_s_duplicatesDuringSuffixation, __pyx_k_duplicatesDuringSuffixation, sizeof(__pyx_k_duplicatesDuringSuffixation), 0, 0, 1, 1},
  {&__pyx_n_s_endingKChangesIntoG, __pyx_k_endingKChangesIntoG, sizeof(__pyx_k_endingKChangesIntoG), 0, 0, 1, 1},
  {&__pyx_n_s_flag, __pyx_k_flag, sizeof(__pyx_k_flag), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_isAbbreviation, __pyx_k_isAbbreviation, sizeof(__pyx_k_isAbbreviation), 0, 0, 1, 1},
  {&__pyx_n_s_isAdjective, __pyx_k_isAdjective, sizeof(__pyx_k_isAdjective), 0, 0, 1, 1},
  {&__pyx_n_s_isAdverb, __pyx_k_isAdverb, sizeof(__pyx_k_isAdverb), 0, 0, 1, 1},
  {&__pyx_n_s_isConjunction, __pyx_k_isConjunction, sizeof(__pyx_k_isConjunction), 0, 0, 1, 1},
  {&__pyx_n_s_isDate, __pyx_k_isDate, sizeof(__pyx_k_isDate), 0, 0, 1, 1},
  {&__pyx_n_s_isDeterminer, __pyx_k_isDeterminer, sizeof(__pyx_k_isDeterminer), 0, 0, 1, 1},
  {&__pyx_n_s_isDuplicate, __pyx_k_isDuplicate, sizeof(__pyx_k_isDuplicate), 0, 0, 1, 1},
  {&__pyx_n_s_isExceptional, __pyx_k_isExceptional, sizeof(__pyx_k_isExceptional), 0, 0, 1, 1},
  {&__pyx_n_s_isFraction, __pyx_k_isFraction, sizeof(__pyx_k_isFraction), 0, 0, 1, 1},
  {&__pyx_n_s_isHeader, __pyx_k_isHeader, sizeof(__pyx_k_isHeader), 0, 0, 1, 1},
  {&__pyx_n_s_isInterjection, __pyx_k_isInterjection, sizeof(__pyx_k_isInterjection), 0, 0, 1, 1},
  {&__pyx_n_s_isNominal, __pyx_k_isNominal, sizeof(__pyx_k_isNominal), 0, 0, 1, 1},
  {&__pyx_n_s_isNumeral, __pyx_k_isNumeral, sizeof(__pyx_k_isNumeral), 0, 0, 1, 1},
  {&__pyx_n_s_isOrdinal, __pyx_k_isOrdinal, sizeof(__pyx_k_isOrdinal), 0, 0, 1, 1},
  {&__pyx_n_s_isPassive, __pyx_k_isPassive, sizeof(__pyx_k_isPassive), 0, 0, 1, 1},
  {&__pyx_n_s_isPercent, __pyx_k_isPercent, sizeof(__pyx_k_isPercent), 0, 0, 1, 1},
  {&__pyx_n_s_isPlural, __pyx_k_isPlural, sizeof(__pyx_k_isPlural), 0, 0, 1, 1},
  {&__pyx_n_s_isPortmanteau, __pyx_k_isPortmanteau, sizeof(__pyx_k_isPortmanteau), 0, 0, 1, 1},
  {&__pyx_n_s_isPortmanteauEndingWithSI, __pyx_k_isPortmanteauEndingWithSI, sizeof(__pyx_k_isPortmanteauEndingWithSI), 0, 0, 1, 1},
  {&__pyx_n_s_isPortmanteauFacedSoftening, __pyx_k_isPortmanteauFacedSoftening, sizeof(__pyx_k_isPortmanteauFacedSoftening), 0, 0, 1, 1},
  {&__pyx_n_s_isPortmanteauFacedVowelEllipsis, __pyx_k_isPortmanteauFacedVowelEllipsis, sizeof(__pyx_k_isPortmanteauFacedVowelEllipsis), 0, 0, 1, 1},
  {&__pyx_n_s_isPostP, __pyx_k_isPostP, sizeof(__pyx_k_isPostP), 0, 0, 1, 1},
  {&__pyx_n_s_isPronoun, __pyx_k_isPronoun, sizeof(__pyx_k_isPronoun), 0, 0, 1, 1},
  {&__pyx_n_s_isProperNoun, __pyx_k_isProperNoun, sizeof(__pyx_k_isProperNoun), 0, 0, 1, 1},
  {&__pyx_n_s_isPureAdjective, __pyx_k_isPureAdjective, sizeof(__pyx_k_isPureAdjective), 0, 0, 1, 1},
  {&__pyx_n_s_isQuestion, __pyx_k_isQuestion, sizeof(__pyx_k_isQuestion), 0, 0, 1, 1},
  {&__pyx_n_s_isRange, __pyx_k_isRange, sizeof(__pyx_k_isRange), 0, 0, 1, 1},
  {&__pyx_n_s_isReal, __pyx_k_isReal, sizeof(__pyx_k_isReal), 0, 0, 1, 1},
  {&__pyx_n_s_isSuffix, __pyx_k_isSuffix, sizeof(__pyx_k_isSuffix), 0, 0, 1, 1},
  {&__pyx_n_s_isTime, __pyx_k_isTime, sizeof(__pyx_k_isTime), 0, 0, 1, 1},
  {&__pyx_n_s_isVerb, __pyx_k_isVerb, sizeof(__pyx_k_isVerb), 0, 0, 1, 1},
  {&__pyx_n_s_lastIDropsAndNotDropDuringSuffix, __pyx_k_lastIDropsAndNotDropDuringSuffix, sizeof(__pyx_k_lastIDropsAndNotDropDuringSuffix), 0, 0, 1, 1},
  {&__pyx_n_s_lastIdropsDuringPassiveSuffixati, __pyx_k_lastIdropsDuringPassiveSuffixati, sizeof(__pyx_k_lastIdropsDuringPassiveSuffixati), 0, 0, 1, 1},
  {&__pyx_n_s_lastIdropsDuringSuffixation, __pyx_k_lastIdropsDuringSuffixation, sizeof(__pyx_k_lastIdropsDuringSuffixation), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_notObeysVowelHarmonyDuringAgglut, __pyx_k_notObeysVowelHarmonyDuringAgglut, sizeof(__pyx_k_notObeysVowelHarmonyDuringAgglut), 0, 0, 1, 1},
  {&__pyx_n_s_nounSoftenDuringSuffixation, __pyx_k_nounSoftenDuringSuffixation, sizeof(__pyx_k_nounSoftenDuringSuffixation), 0, 0, 1, 1},
  {&__pyx_n_s_obeysAndNotObeysVowelHarmonyDuri, __pyx_k_obeysAndNotObeysVowelHarmonyDuri, sizeof(__pyx_k_obeysAndNotObeysVowelHarmonyDuri), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_TxtWord, __pyx_k_pyx_unpickle_TxtWord, sizeof(__pyx_k_pyx_unpickle_TxtWord), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
  {&__pyx_n_s_removeFlag, __pyx_k_removeFlag, sizeof(__pyx_k_removeFlag), 0, 0, 1, 1},
  {&__pyx_n_s_rootSoftenAndNotSoftenDuringSuff, __pyx_k_rootSoftenAndNotSoftenDuringSuff, sizeof(__pyx_k_rootSoftenAndNotSoftenDuringSuff), 0, 0, 1, 1},
  {&__pyx_n_s_rootSoftenDuringSuffixation, __pyx_k_rootSoftenDuringSuffixation, sizeof(__pyx_k_rootSoftenDuringSuffixation), 0, 0, 1, 1},
  {&__pyx_n_s_samePos, __pyx_k_samePos, sizeof(__pyx_k_samePos), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_showsSuRegularities, __pyx_k_showsSuRegularities, sizeof(__pyx_k_showsSuRegularities), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
  {&__pyx_n_s_takesRelativeSuffixKi, __pyx_k_takesRelativeSuffixKi, sizeof(__pyx_k_takesRelativeSuffixKi), 0, 0, 1, 1},
  {&__pyx_n_s_takesRelativeSuffixKu, __pyx_k_takesRelativeSuffixKu, sizeof(__pyx_k_takesRelativeSuffixKu), 0, 0, 1, 1},
  {&__pyx_n_s_takesSuffixDIRAsFactitive, __pyx_k_takesSuffixDIRAsFactitive, sizeof(__pyx_k_takesSuffixDIRAsFactitive), 0, 0, 1, 1},
  {&__pyx_n_s_takesSuffixIRAsAorist, __pyx_k_takesSuffixIRAsAorist, sizeof(__pyx_k_takesSuffixIRAsAorist), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_verbSoftenDuringSuffixation, __pyx_k_verbSoftenDuringSuffixation, sizeof(__pyx_k_verbSoftenDuringSuffixation), 0, 0, 1, 1},
  {&__pyx_n_s_verbType, __pyx_k_verbType, sizeof(__pyx_k_verbType), 0, 0, 1, 1},
  {&__pyx_n_s_vowelAChangesToIDuringYSuffixati, __pyx_k_vowelAChangesToIDuringYSuffixati, sizeof(__pyx_k_vowelAChangesToIDuringYSuffixati), 0, 0, 1, 1},
  {&__pyx_n_s_vowelEChangesToIDuringYSuffixati, __pyx_k_vowelEChangesToIDuringYSuffixati, sizeof(__pyx_k_vowelEChangesToIDuringYSuffixati), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(0, 15, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "(tree fragment)":1
 * def __pyx_unpickle_TxtWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__3 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);
  __pyx_codeobj__4 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__3, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_TxtWord, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_243029568 = PyInt_FromLong(243029568L); if (unlikely(!__pyx_int_243029568)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Word"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Word_Word = __Pyx_ImportType(__pyx_t_1, "Dictionary.Word", "Word", sizeof(struct __pyx_obj_10Dictionary_4Word_Word), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Word_Word) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Word_Word = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Word_Word->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Word_Word)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_7TxtWord_TxtWord = &__pyx_vtable_10Dictionary_7TxtWord_TxtWord;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.__pyx_base = *__pyx_vtabptr_10Dictionary_4Word_Word;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.addFlag = (PyObject *(*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_addFlag;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.removeFlag = (PyObject *(*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_removeFlag;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.verbType = (PyObject *(*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_verbType;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.samePos = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_samePos;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isNominal = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isNominal;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPassive = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPassive;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isAbbreviation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isAbbreviation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isInterjection = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isInterjection;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isDuplicate = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isDuplicate;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isHeader = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isHeader;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isAdjective = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdjective;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPureAdjective = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPureAdjective;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPronoun = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPronoun;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isQuestion = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isQuestion;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isVerb = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isVerb;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPortmanteau = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteau;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isDeterminer = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isDeterminer;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isConjunction = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isConjunction;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isAdverb = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isAdverb;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPostP = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPostP;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPortmanteauEndingWithSI = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauEndingWithSI;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPortmanteauFacedVowelEllipsis = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedVowelEllipsis;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPortmanteauFacedSoftening = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPortmanteauFacedSoftening;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isSuffix = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isSuffix;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isProperNoun = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isProperNoun;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPlural = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPlural;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isNumeral = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isNumeral;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isReal = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isReal;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isFraction = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isFraction;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isTime = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isTime;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isDate = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isDate;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isPercent = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isPercent;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isRange = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isRange;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isOrdinal = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isOrdinal;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.notObeysVowelHarmonyDuringAgglutination = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_notObeysVowelHarmonyDuringAgglutination;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.obeysAndNotObeysVowelHarmonyDuringAgglutination = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_obeysAndNotObeysVowelHarmonyDuringAgglutination;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.rootSoftenDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.rootSoftenAndNotSoftenDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_rootSoftenAndNotSoftenDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.verbSoftenDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_verbSoftenDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.nounSoftenDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_nounSoftenDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.endingKChangesIntoG = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_endingKChangesIntoG;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.isExceptional = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_isExceptional;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.duplicatesDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.duplicatesAndNotDuplicatesDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_duplicatesAndNotDuplicatesDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.lastIdropsDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.lastIDropsAndNotDropDuringSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIDropsAndNotDropDuringSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.takesRelativeSuffixKi = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKi;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.takesRelativeSuffixKu = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesRelativeSuffixKu;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.consonantSMayInsertedDuringPossesiveSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_consonantSMayInsertedDuringPossesiveSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.lastIdropsDuringPassiveSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_lastIdropsDuringPassiveSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.vowelAChangesToIDuringYSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelAChangesToIDuringYSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.vowelEChangesToIDuringYSuffixation = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_vowelEChangesToIDuringYSuffixation;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.takesSuffixIRAsAorist = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixIRAsAorist;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.takesSuffixDIRAsFactitive = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_takesSuffixDIRAsFactitive;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.showsSuRegularities = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_showsSuRegularities;
  __pyx_vtable_10Dictionary_7TxtWord_TxtWord.containsFlag = (int (*)(struct __pyx_obj_10Dictionary_7TxtWord_TxtWord *, PyObject *, int __pyx_skip_dispatch))__pyx_f_10Dictionary_7TxtWord_7TxtWord_containsFlag;
  __pyx_type_10Dictionary_7TxtWord_TxtWord.tp_base = __pyx_ptype_10Dictionary_4Word_Word;
  if (PyType_Ready(&__pyx_type_10Dictionary_7TxtWord_TxtWord) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_10Dictionary_7TxtWord_TxtWord.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_10Dictionary_7TxtWord_TxtWord.tp_dictoffset && __pyx_type_10Dictionary_7TxtWord_TxtWord.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_10Dictionary_7TxtWord_TxtWord.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_10Dictionary_7TxtWord_TxtWord, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_10Dictionary_7TxtWord_7TxtWord___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_10Dictionary_7TxtWord_7TxtWord___init__.doc = __pyx_doc_10Dictionary_7TxtWord_7TxtWord___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_10Dictionary_7TxtWord_7TxtWord___init__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_10Dictionary_7TxtWord_TxtWord.tp_dict, __pyx_vtabptr_10Dictionary_7TxtWord_TxtWord) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TxtWord, (PyObject *)&__pyx_type_10Dictionary_7TxtWord_TxtWord) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_10Dictionary_7TxtWord_TxtWord) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_ptype_10Dictionary_7TxtWord_TxtWord = &__pyx_type_10Dictionary_7TxtWord_TxtWord;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initTxtWord(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initTxtWord(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_TxtWord(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_TxtWord(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_TxtWord(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'TxtWord' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_TxtWord(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("TxtWord", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_Dictionary__TxtWord) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "Dictionary.TxtWord")) {
      if (unlikely(PyDict_SetItemString(modules, "Dictionary.TxtWord", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "(tree fragment)":1
 * def __pyx_unpickle_TxtWord(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_10Dictionary_7TxtWord_1__pyx_unpickle_TxtWord, NULL, __pyx_n_s_Dictionary_TxtWord); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_TxtWord, __pyx_t_1) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "Dictionary/TxtWord.pyx":1
 * cdef class TxtWord(Word):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, name: str, flag=None):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init Dictionary.TxtWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init Dictionary.TxtWord");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* CallNextTpDealloc */
static void __Pyx_call_next_tp_dealloc(PyObject* obj, destructor current_tp_dealloc) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_dealloc != current_tp_dealloc)
        type = type->tp_base;
    while (type && type->tp_dealloc == current_tp_dealloc)
        type = type->tp_base;
    if (type)
        type->tp_dealloc(obj);
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_traverse != current_tp_traverse)
        type = type->tp_base;
    while (type && type->tp_traverse == current_tp_traverse)
        type = type->tp_base;
    if (type && type->tp_traverse)
        return type->tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_clear != current_tp_clear)
        type = type->tp_base;
    while (type && type->tp_clear == current_tp_clear)
        type = type->tp_base;
    if (type && type->tp_clear)
        type->tp_clear(obj);
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
